with {sqgmpga5r0p}:
    if [b'' if '' else 0 for n52i5nmo1rv in [n52i5nmo1rv] for htz9ppxtbdp in not htz9ppxtbdp if None <= n52i5nmo1rv if n52i5nmo1rv]:
        del htz9ppxtbdp
        try:
            break
            htz9ppxtbdp
            from sqgmpga5r0p import n52i5nmo1rv as m548sftftq4
            try:
                pass
            except sqgmpga5r0p:
                pass
            except 0j:
                pass
            except htz9ppxtbdp:
                pass
            finally:
                pass
            yuxzuhua4_3 = yuxzuhua4_3
            match sqgmpga5r0p:
                case True if yuxzuhua4_3:
                    pass
                case {0: None, None: False, 0j: True, **n52i5nmo1rv} if m548sftftq4:
                    pass
                case {False: True, **m548sftftq4}:
                    pass
            for b83lsek3ony in 0.0:
                pass
            else:
                pass
            readkn51oiu: b83lsek3ony = b83lsek3ony
            del yuxzuhua4_3
            mk8kmxuj2yu: sqgmpga5r0p = sqgmpga5r0p
        except {readkn51oiu for v3lfaqfok75 in 0.0 if ...} as ce4md1a4nu0:
            del b83lsek3ony
            break
            while 0:
                pass
            pass
            if b'':
                pass
            else:
                pass

            @sqgmpga5r0p
            async def qix9frkzal3(ofyf_t19gz2=0.0, irsahuj4ppr=0.0, jziwcnxcdwc: v3lfaqfok75=0):
                pass
            async with '' as kuhidxqn_n1:
                pass
            global htz9ppxtbdp
            if ce4md1a4nu0:
                pass
            else:
                pass
            with 0:
                pass
        async for d0lkrnc2e2s in (False for uj2ilhn55z3 in sqgmpga5r0p):
            return 0.0
            match uj2ilhn55z3:
                case {0.0: False, '': False, **kuhidxqn_n1} if ofyf_t19gz2:
                    pass
                case '' if 0j:
                    pass
                case ce4md1a4nu0(None, ofyf_t19gz2=True):
                    pass
            break

            @htz9ppxtbdp
            async def ak4o85dsjxm(k61n4sludtq, llol2lc3erf, g9rpn1l3gnb, mkjco6shah0, ykv_wz0hz65: sqgmpga5r0p):
                pass
            nonlocal b83lsek3ony
            import v3lfaqfok75, v3lfaqfok75, m548sftftq4, kuhidxqn_n1 as o1ou3qr54qd, jziwcnxcdwc as wsi73dhqppv, ofyf_t19gz2, readkn51oiu, wsi73dhqppv

            def fj6p6g1kydk(jk8p1ke8jpy: ykv_wz0hz65, dmbktsfvrw1):
                pass
            del ak4o85dsjxm
            ucuhbc9cym1: None = readkn51oiu

            class ea37cg93apy:
                pass
        break
        for pa807yz1582 in (yield 0.0):
            q4q7wrh_i1g -= None

            class t7dg9vt32ow:
                pass
            match mkjco6shah0:
                case None:
                    pass
                case _ as v3gwlkimuto if False:
                    pass
                case {0.0: 0j, None: 0.0, False: b''} if None:
                    pass

            @t7dg9vt32ow
            class v7wd81kt9hx:
                pass

            def n6tl1r18oot(fewnhoq6xxq: pa807yz1582='', iu4lkrr2hs1=0, x89vqn5a2nn=0, dvmax_w5lck: o1ou3qr54qd=0.0, c6rt4kpd7xq=0, wpo25xupcgu: wpo25xupcgu=False, yt08h0pkrx1=None, u_blwm4ws3t=0.0):
                pass
            jsn9kezaihf: mk8kmxuj2yu = c6rt4kpd7xq
            ez_fkbwukqr <<= ...
            nonlocal ce4md1a4nu0
            with 0j, False:
                pass
            dmbktsfvrw1
        while '':
            ie9oqjderx3: 0.0 = b''
            nonlocal dmbktsfvrw1
            match None:
                case '':
                    pass
            while pa807yz1582:
                pass
            else:
                pass
            try:
                pass
            except ie9oqjderx3:
                pass
            else:
                pass
            assert ''
            global v7wd81kt9hx
            y4hlvm_6mm5 = jsn9kezaihf

            def fywpkdtqbwb(vyb9lb56gra: v3lfaqfok75=False, m5xwv4gxtuy: ie9oqjderx3='', z9kfzp7o534=0j, wsrz2fvykwd='', gn4h3d1qmxx=0.0, yti_rhdssz0: irsahuj4ppr=False, l0agd2mmkqu=0j, g_elvj_b1bz: ez_fkbwukqr=b'', h61451h9lwc='', cgbl28agk8y=b''):
                pass
            for dfo6rj7m8js in ie9oqjderx3:
                pass
            else:
                pass
        else:

            @ofyf_t19gz2
            @0.0
            @0.0
            def hxu34rf63g2(hgays8g73v7: cgbl28agk8y=0j, zxcmxqvsfpp: fewnhoq6xxq=0j, hqav0ywi86e=0.0, bxdxx9s_g68=0, xooa5nl1c3n: jziwcnxcdwc=0j, symjo7yo0wm: b83lsek3ony=0.0, owxaoajg729='', t80_35ujrz6=None, n9m132zdifh=False):
                pass
            async with v3lfaqfok75 as ic4kspjp5jx, 0.0 as a8dz_hp6_y6:
                pass
            for h3wd5i9xtfk in x89vqn5a2nn:
                pass
            from y4hlvm_6mm5 import hgays8g73v7, bxdxx9s_g68 as buryiics6r5
            raise 0.0
            assert a8dz_hp6_y6

            @gcegnjc6of5
            async def s2_xv5mlkht(gcegnjc6of5, iazi22g8n0c: readkn51oiu, h_jbe34klud, l1iww84garm, ezmvcl1h64m, bvkjgtzkj7h, dyyjmctxhig: wsi73dhqppv, qz_vajlmmcu: owxaoajg729, gofrunif4fv: m548sftftq4):
                pass
            import ezmvcl1h64m, hgays8g73v7, m5xwv4gxtuy as e_avlke666m, gcegnjc6of5 as uq4alf6vv54, u_blwm4ws3t as npbid5gixvx, ic4kspjp5jx as ls96x05msv_, hgays8g73v7, fywpkdtqbwb
            assert 0j, 0.0

            class tyu5s_hiyw7:
                pass
        cae_z9vpi0n *= {jziwcnxcdwc: iazi22g8n0c}
        nonlocal c6rt4kpd7xq
        continue
        nonlocal h_jbe34klud
    x7ej6bqwia2 = dvmax_w5lck
    import zxcmxqvsfpp, s2_xv5mlkht, readkn51oiu as nl13np8k5ae, v3lfaqfok75, readkn51oiu, n52i5nmo1rv, u_blwm4ws3t, yt08h0pkrx1
    global mk8kmxuj2yu
    for bxg4evbg5zl in {ak4o85dsjxm}:
        break
        pass
        nonlocal g9rpn1l3gnb
        assert npbid5gixvx('', None, m548sftftq4=hgays8g73v7, qix9frkzal3=h3wd5i9xtfk), gofrunif4fv(x7ej6bqwia2, d0lkrnc2e2s, ce4md1a4nu0=k61n4sludtq)
        async with (yield ucuhbc9cym1) as ff5vwq42jo7, (mk8kmxuj2yu for vtbtlzldb9h in 0j if 0.0 if b'' if h61451h9lwc) as k3bwyxq6hyl:
            bubwvh63sts: None = 0.0
            while None:
                pass
            else:
                pass
            zlfki6rd41x = ''
            if m5xwv4gxtuy:
                pass
            with yti_rhdssz0 as dzvusrmclu0, ak4o85dsjxm as bkijgzdujiz, 0 as e9fshgr3pws:
                pass
            continue
            continue
            while 0j:
                pass
            else:
                pass
            continue
            return
        freq9omzwzi = None

        def z2b56hlwg7p():
            assert nl13np8k5ae, 0
            assert mkjco6shah0
            assert ..., None
            for ufv8kmvz1ls in mk8kmxuj2yu:
                pass
            else:
                pass
            if x7ej6bqwia2:
                pass
            else:
                pass
            alvy2ym_u0p: zxcmxqvsfpp = ce4md1a4nu0
            async for n_5f35zr1o6 in ...:
                pass
            else:
                pass
            fsa2jyk4p4y *= alvy2ym_u0p
            assert vyb9lb56gra
            match e_avlke666m:
                case [True]:
                    pass
        async for rhrlc7_ncti in {False, llol2lc3erf, '', '', d0lkrnc2e2s, sqgmpga5r0p, b''}:
            cjht6ary31x = m5xwv4gxtuy
            w0th4o7h9t0: ie9oqjderx3 = qix9frkzal3
            pssuas19ubm %= ''
            while fsa2jyk4p4y:
                pass
            async for kli0bt02tfk in b'':
                pass
            else:
                pass
            with wpo25xupcgu as a7pxk0irpba:
                pass
            try:
                pass
            except ... as r392a4bif8k:
                pass
            except e9fshgr3pws:
                pass
            else:
                pass
            finally:
                pass
            try:
                pass
            except yt08h0pkrx1:
                pass
            else:
                pass
            finally:
                pass
            import jk8p1ke8jpy as cauyfscuxmw, bxg4evbg5zl, k61n4sludtq, kli0bt02tfk, x89vqn5a2nn, bvkjgtzkj7h, ufv8kmvz1ls as q_tp7nrs0cb, c6rt4kpd7xq as q1fzsop81_w
            break
        else:
            from jsn9kezaihf import fj6p6g1kydk as z94kakal2os, t80_35ujrz6 as z1g1ybwxb64, qix9frkzal3 as ke6ulhq9rvg, wsi73dhqppv
            continue
            from bvkjgtzkj7h import o1ou3qr54qd, l0agd2mmkqu, vyb9lb56gra, wsi73dhqppv as umy6f_i3e7d, n9m132zdifh as zdsfecpq_xp, d0lkrnc2e2s as dadpj95s5ca, llol2lc3erf, gn4h3d1qmxx as zn_xkgm2v77
            global t7dg9vt32ow
            nonlocal jsn9kezaihf
            raise b''
            async with b83lsek3ony as w_lewsezryz, cjht6ary31x as nr_1th7wesh, zxcmxqvsfpp:
                pass
            swibthj7s61 <<= ea37cg93apy

            async def dpzynsxmek7(xocdxv9tg6o, m9b0knt0jqd, g3_2kpfsv_4, tm_8iuyoz99: z94kakal2os, knbfrpv4d2g: g3_2kpfsv_4, adznipilaxj: ls96x05msv_, ucor_neakky: jk8p1ke8jpy):
                pass
            continue
        ufvlxnm4zmq = zpqxxezx4wo = zeslyg99hf0 = kbnyicy6751 = t1ppifjnv1d = nx3p_1c0jib = ny45janjy7t = zc4ac2eac7p = lambda yhoat5yf_88, fj6_647u4hs, kh919h0rxjr, papnbory2cq, i4mr_4on1mz, kg1v7vr6drh, rtjvs9i9oht, xkwi_vthqtl, mzaot9nfgpm, v7vbv9_fvd1: zeslyg99hf0
        pass
    while '':
        async with b'' < xooa5nl1c3n == None as xh66p2652q1:

            async def ecit4quvowa(jovd3dgp_ix, un1gq93sr2m: b83lsek3ony, nhw_2e3qr9v: jsn9kezaihf, t6_iofpjimg: u_blwm4ws3t, mjglnn0iv2s, jki_mnozem7, r488newojf9: jziwcnxcdwc, vt2xeddne_w: ezmvcl1h64m, yiemcg_4njd: q4q7wrh_i1g, ssp_x1f07d2: readkn51oiu):
                pass

            def fczxto1dgto(znuvgz6xul8, q7lw9sdeur2: ce4md1a4nu0, hn_z9fo5o31: r488newojf9, v4sccnh4yrc, j0abzpfqcga, b329_kq2_qh: i4mr_4on1mz):
                pass
            for nlxx94qo9j1 in ...:
                pass
            else:
                pass
            try:
                pass
            except 0.0:
                pass

            class m56h5x7fk9d:
                pass
            break

            def cpbwkw7lm4k(ssyu50a51ey: swibthj7s61=False, k4bwy64cd_x: h_jbe34klud=0, nxkoh2mop6q='', va1002i7e3m=b'', anx4p40z4qr: zlfki6rd41x='', g3o1d0ojvh9: l1iww84garm=b''):
                pass
            match dadpj95s5ca:
                case True:
                    pass
            import s2_xv5mlkht as nenib1jd6kq
            async with 0.0:
                pass
        match [fsa2jyk4p4y for mvak9_qlp0t in kbnyicy6751 if ofyf_t19gz2 if False if b'']:
            case False if {qz_vajlmmcu: 0 for rn_js40iocj in b329_kq2_qh if b'' if bvkjgtzkj7h}:
                match 0.0:
                    case eoaksaulaa2 | _ | 0 if sqgmpga5r0p:
                        pass
                tuzbsei2rrl = rv_kpilg2ko = l7z4oxbesbp = 0j

                @n52i5nmo1rv
                @0j
                class apk1_k2ocpz:
                    pass
                nonlocal kuhidxqn_n1
                return ''

                @rv_kpilg2ko
                @None
                @False
                class kjqkt5t9aac:
                    pass
                while b'':
                    pass
                else:
                    pass
                nonlocal papnbory2cq
                zeslyg99hf0
                assert cpbwkw7lm4k, iu4lkrr2hs1
            case 0.0 if [None for j0dalhjsbc_ in False if b'' for km92saqr3v6 in False if '' if ...]:
                while anx4p40z4qr:
                    pass
                del znuvgz6xul8
                with gcegnjc6of5 as dz3xxaug2sk, k61n4sludtq as uxsp780v4jm, a7pxk0irpba as ezvb2p_u74t:
                    pass

                async def gu4oukt98bf(kpopsgul74d: kjqkt5t9aac, v324hgt4q0z, v40hqb8t2lm, ft85t2o5_a0, lzm_ywcn7i0: dpzynsxmek7, ub58vyejjwl, kuzmybbhndq: h3wd5i9xtfk):
                    pass
                del n6tl1r18oot
                with kuhidxqn_n1 as g382gdwhtg1:
                    pass
                async with dmbktsfvrw1 as rllsny539sy, 0.0:
                    pass

                @0
                @knbfrpv4d2g
                @0.0
                class yrakv8ye_ak:
                    pass
                from iazi22g8n0c import eoaksaulaa2, fj6_647u4hs as n0li_gihazj, mzaot9nfgpm, ea37cg93apy as u56ih5rle9y, readkn51oiu, hqav0ywi86e, hxu34rf63g2, sqgmpga5r0p as wzfvb6wvmxr

                class jmip_c3utiq:
                    pass
        async for qptboytvoz5 in xh66p2652q1:

            class d9lpzrr01od:
                pass
            ew3n0t0wzey: b'' = km92saqr3v6
            return un1gq93sr2m

            @fj6p6g1kydk
            @e_avlke666m
            async def nzcrw6nfpbo(wkcdi2bnrmx: j0abzpfqcga, zkhzpg0tnpp, ir5s2fery6k: mkjco6shah0, la0y6pul3oe: z94kakal2os, qaipt7revt3, yfmqd1l5a9c: j0abzpfqcga, gmhrugwdb68: ezmvcl1h64m, hhgg2yw52l5, oxrpxbosfqe: vyb9lb56gra, vnrga7wvmb0):
                pass
            from wkcdi2bnrmx import g_elvj_b1bz as k5_095nt48r
            wrfvvlzps2t: kh919h0rxjr = 0.0
            nonlocal qz_vajlmmcu
            continue
            import rllsny539sy as k5vm8zi5rv0, ufv8kmvz1ls, s2_xv5mlkht as sjat98r6ap7, v7vbv9_fvd1 as uo3cmchkkig
            q2yh37d4kdg: fczxto1dgto = 0.0
        else:

            async def w9b25ffy_wn(a9l0fkokk_t=0j, qe4la99vsp2: w0th4o7h9t0=0, qgwlcx12da9='', oj1gb7ou6ey: zc4ac2eac7p=0j, e48l1i_o3vy=False, juto5vmvpz_=b''):
                pass
            with m5xwv4gxtuy, ea37cg93apy as ymika3uqp16, hhgg2yw52l5 as ebhw239a2st:
                pass
            while ...:
                pass
            else:
                pass
            assert ..., xocdxv9tg6o
            a_b2hhdg48l: 0 = ls96x05msv_
            from h_jbe34klud import t6_iofpjimg as npb1t09ff9r, qptboytvoz5, z1g1ybwxb64 as djn3e8jqah1, llol2lc3erf as vp955_n5_4k, qz_vajlmmcu, tm_8iuyoz99
            bg5uidv3bjv = ...
            pass
            import nlxx94qo9j1 as duhfa52cx58, oj1gb7ou6ey, ssyu50a51ey as c85_o2dxucb, un1gq93sr2m, dvmax_w5lck as kuoxd70b767, r488newojf9 as mxut6v1az14
            z2v6q7xpejk //= tm_8iuyoz99
        break
        async with {... for upwg4wsmbel in False if dz3xxaug2sk if 0j if ... for xnqzgm5lufh in 0.0}, {yt08h0pkrx1 for l5eqtomoc1p in 0.0 if nr_1th7wesh if ucuhbc9cym1 if ir5s2fery6k for azxkcdx83x1 in u56ih5rle9y} as p4fcibh226y:
            global vp955_n5_4k
            assert None, ''

            @0.0
            @cae_z9vpi0n
            class cfxw05vbh9a:
                pass
            nonlocal bvkjgtzkj7h

            @k3bwyxq6hyl
            @sqgmpga5r0p
            @''
            async def fj4txhmqntt(pzbemyvnneu='', vf0dhzd160z=None, bbxajaxvk60=b'', q7hi71acubr: gcegnjc6of5=False, kqo4i3deyj6: xooa5nl1c3n='', s9rds9c4dzy=b'', rvndcjx2h10=0j, ubaf0ml9twc=False, vda9ch0hbj7: pa807yz1582=0):
                pass

            @False
            @w0th4o7h9t0
            def dokiqgbg61_(gpirdwue87g, zsd1y7oxw8r: q1fzsop81_w, b4pkddpcye7: s2_xv5mlkht, p90i1ibqjj2):
                pass
            from dpzynsxmek7 import t1ppifjnv1d as nfyx1iq3xf8, ucuhbc9cym1, dvmax_w5lck as xfdgb0ryhpp, m548sftftq4, w9b25ffy_wn as mp5wlzyonpz
            global ic4kspjp5jx
            with v40hqb8t2lm, ..., 0 as yxbdcvi2bbs:
                pass
            break
        o6uzlt4rfeh: freq9omzwzi / 0j = [0.0 for ptc3u3twyut in n_5f35zr1o6]

        @f'bn210es_laq{ssp_x1f07d2}onz1gzgf6sk{h_jbe34klud}k3rybh1yujf{ce4md1a4nu0}{hqav0ywi86e}{v7wd81kt9hx}g_swlqrmou9{ie9oqjderx3}'
        def n8yrehnhksd(p2u9rmeq2j0: ucor_neakky, veikyvovkfw, pmzl_j8w6l6: yt08h0pkrx1, j9yyv3_4vfp):

            class tfn202zoa9z:
                pass
            del l7z4oxbesbp
            with None, ic4kspjp5jx, ...:
                pass
            nonlocal duhfa52cx58
            async for bbwvhc82yw7 in buryiics6r5:
                pass
            else:
                pass
            vfc15ulo5zg: tuzbsei2rrl = tm_8iuyoz99

            def g8cpm0n6zbt(egtwlg7k7bq: ebhw239a2st=0.0, bw4jhgjrh1h: azxkcdx83x1=0, mq4_uqgkcow: ptc3u3twyut='', rlz_jmp8d07='', vn3no0uv062=None, cuistwjyc8s: c6rt4kpd7xq=b'', bea9y5t8adr=0.0):
                pass
            ufw5tl5f1xu /= freq9omzwzi
            if b'':
                pass
            continue
        m1zl59o1a3f += 0.0 // b''
        raise [... for vox6064ad1c in cfxw05vbh9a for t0wx_0fcy5_ in None if hhgg2yw52l5 if g_elvj_b1bz if p4fcibh226y]
        if [ew3n0t0wzey, km92saqr3v6]:
            assert n6tl1r18oot, yhoat5yf_88
            async for eo_3sw0nltp in '':
                pass
            else:
                pass

            class a8rwzlpry70:
                pass
            async for ukhk08z7owc in 0:
                pass
            papnbory2cq
            pf8imjhewuv: qgwlcx12da9 = hn_z9fo5o31
            from ymika3uqp16 import j9yyv3_4vfp as rwlge6hcfnq, m9b0knt0jqd as khu1gi59mtt
            async for mp2bslp_aak in False:
                pass
            del ny45janjy7t
            0j
    else:
        continue
        while '' if None else 0.0:
            import qz_vajlmmcu as jovtql54iqc, t0wx_0fcy5_ as vdnbu6tgfas, h61451h9lwc as o37s84rdi48
            assert False, None

            @tm_8iuyoz99
            @''
            class m3p2747lxg4:
                pass
            global sjat98r6ap7
            import kuoxd70b767 as lws8h3h47ih, n8yrehnhksd, h61451h9lwc as f581xekc1eb, l1iww84garm, g382gdwhtg1, eoaksaulaa2 as d356jvog0_n, k5vm8zi5rv0 as xm8iq1ks_fz
            if ie9oqjderx3:
                pass
            ea37cg93apy
            break
            while rllsny539sy:
                pass
            else:
                pass
            del a7pxk0irpba
        else:
            from o6uzlt4rfeh import papnbory2cq, l7z4oxbesbp, eo_3sw0nltp as vyxh93fnlxf, uj2ilhn55z3, la0y6pul3oe as r3g1yj5m57e, ufvlxnm4zmq as hmy6lkkn1xx, j9yyv3_4vfp, a7pxk0irpba as ehes6eof628, q7hi71acubr as kiz4a65sd9y
            async for k_wobyq7fdq in alvy2ym_u0p:
                pass
            raise False
            match d356jvog0_n:
                case r392a4bif8k(None, True, False, b329_kq2_qh=True):
                    pass
                case [b'', *fj6p6g1kydk]:
                    pass

            @0
            class idqyarawz20:
                pass
            match ...:
                case _:
                    pass
                case dhddkgs1bga as disux_s82is:
                    pass
                case False:
                    pass
            nonlocal gn4h3d1qmxx
            import kli0bt02tfk, f581xekc1eb, t6_iofpjimg, k5_095nt48r
            match 0.0:
                case None:
                    pass
            nonlocal n_5f35zr1o6

        @0j
        @f'gdi4vklqffb{ke6ulhq9rvg}hatx9oje7pkemihcvanauc{knbfrpv4d2g}{j0dalhjsbc_}{khu1gi59mtt}{fewnhoq6xxq}{ft85t2o5_a0}v5f7xlk1pxg'
        class amt065ph8nk:
            from kbnyicy6751 import kuoxd70b767, a8rwzlpry70 as k2opahbhcht
            cxrt6qej6ba = ipq7d9v_ouz = hwr66r5rnr8 = vl23mt_zq95 = op6_8g7dke2 = e_m2eqe7w8r = tzqny1_s7fe = py5td0ss8a6 = p9pwxrumenq = la0y6pul3oe
            break
            with v3lfaqfok75, ssyu50a51ey as l_qes5iz9ft, b'':
                pass
            match ...:
                case _ if ezvb2p_u74t:
                    pass
                case False:
                    pass
            mkjco6shah0
            pass
            continue

            @0
            @False
            @b''
            class zpvthj2vn66:
                pass
            assert b''
        if (yield b''):
            from t0wx_0fcy5_ import lws8h3h47ih, c6rt4kpd7xq, q1fzsop81_w, bxg4evbg5zl, egtwlg7k7bq as e91d9kxrak_, a8dz_hp6_y6 as xuj3rlqk2_d, vox6064ad1c as w6wb2sgyw_m, cauyfscuxmw as jh9xr2gih5x
            break
            return False
            with 0.0 as tzrn_y_fd9e, qz_vajlmmcu as qrt9iu7jalc:
                pass
            async for pn1yh6ftdge in mxut6v1az14:
                pass
            else:
                pass
            del npb1t09ff9r
            match mp2bslp_aak:
                case {'': b'', 0j: False} if c85_o2dxucb:
                    pass
                case _ if jki_mnozem7:
                    pass
            continue

            @disux_s82is
            @0j
            @0j
            async def rrw4uc4kfor(mou4_ixpi2z: m3p2747lxg4, uk7qg_4jz3h, ug9cfgf6ojx, y4fvjbqyo50: jsn9kezaihf, btdhrat1u6h, go03fmdkb1p, aahcv77kob4: p90i1ibqjj2):
                pass

            class fk6t77r7cme:
                pass
        import gcegnjc6of5, bg5uidv3bjv as kk16vp4b9oc, yuxzuhua4_3, k61n4sludtq, kuhidxqn_n1, wrfvvlzps2t, e48l1i_o3vy
        return
        raise (0.0 for ha980qslbh5 in kuhidxqn_n1 if False if xocdxv9tg6o if 0j for habmzpb0dsb in a_b2hhdg48l)
        for srcj8xamn4x in {False for fatnjime3mp in jovd3dgp_ix if 0.0}:
            try:
                pass
            except b'':
                pass
            except '' as ye1fsccotf8:
                pass
            except ...:
                pass

            @b''
            class vj74l20jslo:
                pass
            async for wrj2d8v2xfi in cgbl28agk8y:
                pass
            break
            pass
            break
            raise ''
            nonlocal yfmqd1l5a9c
            global umy6f_i3e7d
            lhxfhd5v4d9: ... = ''
        else:

            class lfrqkxvcwo1:
                pass
            nonlocal bxg4evbg5zl
            for gfudgtmw497 in False:
                pass
            else:
                pass
            0
            for qzh__dg0ii2 in buryiics6r5:
                pass
            match '':
                case {False: '', False: 0j, **xfdgb0ryhpp} if 0:
                    pass
                case None if s9rds9c4dzy:
                    pass
                case _ | z_mdt0gl586:
                    pass
            assert lws8h3h47ih
            global juto5vmvpz_
            with h61451h9lwc, un1gq93sr2m as x_mnht6a042, yhoat5yf_88:
                pass
            async for x8oj8vc3yd8 in ...:
                pass
            else:
                pass
        async with x8oj8vc3yd8 if '' else yt08h0pkrx1, lambda: ... as lkkgt39ru3z:
            kgs0daq8w3l += ...
            if qz_vajlmmcu:
                pass
            else:
                pass
            return lhxfhd5v4d9
            if b'':
                pass
            from cuistwjyc8s import wzfvb6wvmxr, gofrunif4fv as d3_bf6o2mxw

            def vzbhw3nrt7b(i9x5ojyfrmh=False, aqt6q8pyxjc=0, mferpwa170a: t1ppifjnv1d=0j, szfkmmuntp0=0, vfl_zxmuxs1: ew3n0t0wzey=0, k78ujl6bkux: nenib1jd6kq=False):
                pass
            break
            try:
                pass
            except 0j:
                pass
            except 0 as k353muv2c4h:
                pass
            except q7lw9sdeur2 as kqhq1u9jgok:
                pass
            finally:
                pass
            match 0.0:
                case 0j:
                    pass
            pass
        with {vdnbu6tgfas for mjcqb09youg in bea9y5t8adr if 0 if 0.0} as b0lnxa8xp2f:
            raise kjqkt5t9aac
            del anx4p40z4qr
            break
            while apk1_k2ocpz:
                pass
            async for lp1rn8r3pzd in ...:
                pass
            break

            def hljejak28id(aruc54gfl7z, r8kmvs_1ny9: n_5f35zr1o6):
                pass
            if 0j:
                pass
            0
            for k3pdlua4lsw in b'':
                pass
            else:
                pass
    with ([e91d9kxrak_ for lopg0g0ipd_ in tyu5s_hiyw7 for ocehndmhg_n in n6tl1r18oot if vj74l20jslo if a_b2hhdg48l], {...: 0, idqyarawz20: b'', emihcvanauc: b'', 0.0: '', m3p2747lxg4: b'', y4hlvm_6mm5: False, 0: i4mr_4on1mz, ...: a9l0fkokk_t}, (yield fywpkdtqbwb)):
        import q_tp7nrs0cb, s9rds9c4dzy, l5eqtomoc1p as bu_yrduwt28, szfkmmuntp0, vdnbu6tgfas as n973czbd6m1, d0lkrnc2e2s, hn_z9fo5o31 as k4c6datpa3e
        raise (yiemcg_4njd,)
        nonlocal uo3cmchkkig
        global qaipt7revt3
        j6u5j737pax -= await v5f7xlk1pxg
        mp5wlzyonpz
        while {aruc54gfl7z, '', ykv_wz0hz65, b'', jziwcnxcdwc, gmhrugwdb68, '', fewnhoq6xxq, llol2lc3erf}:
            pass
            async for ypaw_nv970d in ofyf_t19gz2:
                pass
            else:
                pass
            async for rp2dbn2uoko in idqyarawz20:
                pass
            else:
                pass
            break
            del ufv8kmvz1ls
            async with 0j as iag7a91otvk, None, None:
                pass
            break
            import ptc3u3twyut as e1d24_p0fqa, ie9oqjderx3 as adua17w6kke, dpzynsxmek7, ocehndmhg_n as tjgv5pydhdg, ptc3u3twyut as vxipu3d3v_h, htz9ppxtbdp, k61n4sludtq as k38rx353ocq, ufv8kmvz1ls as el1x_dts3ug
            while ufv8kmvz1ls:
                pass
            else:
                pass

            @...
            @yuxzuhua4_3
            @e48l1i_o3vy
            async def wb3pqk50iaj(xhvtf2ahxdu: cjht6ary31x, y6tfbe34_bw: dfo6rj7m8js, jsxa6dqy76r: vfc15ulo5zg, wr6pzimbhnm):
                pass
        v8b9hfwjc5i = r76oyfolcgb = wep7zd_2pc2 = (False for zlffejmm8e3 in False for v00jry2wmrp in 0.0 if ie9oqjderx3 if zlfki6rd41x for uk5ucnr3mmg in 0.0 if d356jvog0_n if w0th4o7h9t0 if 0)
        break
        nonlocal aruc54gfl7z
    return
    async with (kli0bt02tfk < e1d24_p0fqa) / [qptboytvoz5 for lbadpvfwyg4 in False if g3_2kpfsv_4 if b'' if ''] as ttg9gk2seqq:
        assert ...
        async for ya_1qtywixm in (yield e9fshgr3pws):
            global jsxa6dqy76r
            global zlffejmm8e3
            del cgbl28agk8y
            import k3rybh1yujf, uq4alf6vv54 as uccu9wefelz, pf8imjhewuv as uevxfu2ph25
            eo_3sw0nltp
            break
            with 0j as wcy1l6pkgup, ce4md1a4nu0 as luyv97qs3sg, jmip_c3utiq:
                pass
            with b'' as og34nueuc0_, 0 as a20yqhy2i9t, 0j as babwh7ufrbi:
                pass

            @None
            async def w4hficr_mvl(f33g9xpkdpu: cfxw05vbh9a, e61pbxs_6x_, d3obnxwits7: uevxfu2ph25, r6d5_8akv6d):
                pass
            break
        else:
            if '':
                pass
            else:
                pass
            pass

            @iazi22g8n0c
            @gdi4vklqffb
            def de_n520vjzf():
                pass
            dv6b87h6nft = o9lrioay22_ = ra9ublc7mdv = c32_ae_mcss = ozjbvnj8tbn = tob8fdiw61v = c7ayfeeqxgg = zdsfecpq_xp
            global ptc3u3twyut
            break
            async for y9l22o4wak4 in b'':
                pass
            raise kiz4a65sd9y
            for xm2w9s_wyza in nzcrw6nfpbo:
                pass
            match j0dalhjsbc_:
                case _:
                    pass
                case False if ...:
                    pass
                case 0.0:
                    pass
        try:
            return
            raise kbnyicy6751
            async for j8ill_rk53p in None:
                pass
            else:
                pass

            @q2yh37d4kdg
            @uk5ucnr3mmg
            async def z7dms_jovuz(g1zr7cb9xbs: og34nueuc0_=b'', kxh4y4nys_9: b4pkddpcye7=False, xueh_ucu78e: rrw4uc4kfor=None):
                pass
            assert ''
            raise kiz4a65sd9y
            break
            while fk6t77r7cme:
                pass

            @ya_1qtywixm
            @''
            @qix9frkzal3
            class e2omjxcidl3:
                pass
            async for n7gaa8of8ni in oxrpxbosfqe:
                pass
        except (aahcv77kob4 for gpxkzaydmll in lopg0g0ipd_ for m4m8448vlfc in 0.0 for rungkcybcky in habmzpb0dsb if p90i1ibqjj2) as rvdv9kticfn:

            @fsa2jyk4p4y
            @h_jbe34klud
            async def wt12z3tmwz3(qzjcjn76x7k: z_mdt0gl586, dou6d7qgbxq: ye1fsccotf8, znts9yqt39g, bkw1jtkcs2m, ujdvvwscz4s, lu6qfwlas1i, wb7a440fdlz, igqey37t2l5: hxu34rf63g2, afurt7n3xt9, i38srge_13t: dmbktsfvrw1):
                pass
            from bubwvh63sts import xocdxv9tg6o
            try:
                pass
            except uj2ilhn55z3 as qr6hr3xxbbk:
                pass
            except False as e_wf17_5pw6:
                pass
            global k4bwy64cd_x

            @fk6t77r7cme
            async def nlanl6yob9i(j4_si27mg2s=0j, u38hb_csli6: tfn202zoa9z=0.0, wgxxx23b03u=b'', k845f2dbpvi: ssyu50a51ey='', foluaknd6w6=0, fnog4nob0mh=False, rwpc5f3wp2n: i9x5ojyfrmh=None, szqwxvag7pc=0.0, petsbkmp397: k4c6datpa3e=0j):
                pass
            global gofrunif4fv
            pass
            pass

            @el1x_dts3ug
            @dvmax_w5lck
            @w4hficr_mvl
            class iwi90ew44xr:
                pass
            nonlocal xhvtf2ahxdu
        finally:
            import tzqny1_s7fe, b329_kq2_qh, jsxa6dqy76r as mghv3dsh3m3, fsa2jyk4p4y, k5vm8zi5rv0, ufv8kmvz1ls as otxril9vim7, xm8iq1ks_fz as hf0r6yn7_v9, vdnbu6tgfas as m23b7jbu4jm, qzjcjn76x7k as n1zkdj3g02k
            return None
            qaeemsz7z7p //= ''
            assert mq4_uqgkcow, b''
            import nenib1jd6kq as hdly_ii8cfe, yti_rhdssz0 as tsl4g14_6kt, jki_mnozem7 as yt2oe90noon, e_avlke666m, ya_1qtywixm as h91k9eoas7l, dzvusrmclu0, vtbtlzldb9h, r488newojf9, o6uzlt4rfeh as x_7n_tonhc5
            if 0j:
                pass
            with s2_xv5mlkht, False:
                pass
            raise b''
            async with h_jbe34klud as qap5kpdhv9b, False as dkcuct6tsou:
                pass

            def lc5k97wti9y():
                pass
        0j if False else ''
        ick4d_6v6ut: (k3rybh1yujf, xfdgb0ryhpp, cauyfscuxmw) = bea9y5t8adr
        nonlocal mk8kmxuj2yu
        t8b13ubjakr &= {e_wf17_5pw6: ''}
        w2gtzy_qhat: {0, wcy1l6pkgup, ..., 0j, jziwcnxcdwc, '', 0j, va1002i7e3m} = 0j(l0agd2mmkqu, ft85t2o5_a0, r392a4bif8k=False)
        f'{k3rybh1yujf}{lws8h3h47ih}{lhxfhd5v4d9}ctcigddez8trhmaver4ixw{m3p2747lxg4}{n8yrehnhksd}{ug9cfgf6ojx}{qrt9iu7jalc}{b83lsek3ony}'
        async for xe7bslz29xg in f'{wep7zd_2pc2}{rlz_jmp8d07}q6bqcwufyut{babwh7ufrbi}e5l93wrt51kln7dqz1185ft_w_np4z2fbzfxxt4wl4doct_xp1zuhvo{e_avlke666m}':
            if l_qes5iz9ft:
                pass
            return

            def oiqrovkiasq(s3tt2g_ng79=0j, fgqt7ezgsqm: v7wd81kt9hx=0, e5bwx2jdduo: v8b9hfwjc5i=0, rms2sjkskm6='', gdbq1qtsgym=0j, u962hl50hiw: vfl_zxmuxs1=0j, e22wc6sbltf=0j):
                pass
            async with 0.0 as uwlmcxl4_wi, dpzynsxmek7:
                pass
            from djn3e8jqah1 import ir5s2fery6k, k_wobyq7fdq as ncsa8y8oawz, szqwxvag7pc as n7hxcjx5ieq, dz3xxaug2sk, n973czbd6m1 as cra2of6mq1u, ce4md1a4nu0 as ghggtz6hknh, y9l22o4wak4 as zt1u0mtxo1y
            if ...:
                pass
            async for tlxnjhqvc0x in d356jvog0_n:
                pass
            try:
                pass
            except de_n520vjzf:
                pass
            else:
                pass
            zzp0psa7rqd: '' = ''
            import y4hlvm_6mm5 as rpiybl0q0f8, n7gaa8of8ni
        else:
            z2b56hlwg7p
            try:
                pass
            except h3wd5i9xtfk as rv061x8q4me:
                pass
            except b'':
                pass
            match kbnyicy6751:
                case z1g1ybwxb64(None, None, False, eo_3sw0nltp=False):
                    pass
            if cuistwjyc8s:
                pass
            None
            continue
            ypoaq4z5_kk: 0.0 = 0
            async for g5sfw2ec9ax in b'':
                pass
            with None as p001wyzu_4s, 0j as e346i20fjtf:
                pass
            ...
    cq4uam2p17z = d6wx80a9dnw = vxzab640kdx = ngj9l_46_jt = aglhwtokbg4 = ik9mxismhou = [lambda wufpk2v7ifg: False for jm84xuu8qhy in {g_swlqrmou9, afurt7n3xt9, npb1t09ff9r, 0, 0, b'', n6tl1r18oot} if (0, b'') if {ehes6eof628} if {n_5f35zr1o6} for lw314b50_6o in {w6wb2sgyw_m for skef4v6j5mp in None if b''} if 0 if (yield from 0.0)]
lc3jmfm2vaw >>= (yield (None if False else '')) < await 0 | (ngj9l_46_jt) is {aqt6q8pyxjc: 0j if ufv8kmvz1ls else kbnyicy6751, await kjqkt5t9aac: n52i5nmo1rv @ 0, y4fvjbqyo50 <= False <= egtwlg7k7bq: (ke6ulhq9rvg, lfrqkxvcwo1), (yield 0.0): b'' in g3_2kpfsv_4}

@+(yield (lambda km0ugd0g9c0, g1_9y4f6q2g, pl7d2d9q3__, fdvwnt2ww1f, wqzy6o7uye4, jlgd9tzt6aq: 0j))
def by0v50dzfmq():
    global otxril9vim7
    global rms2sjkskm6
    break
    nonlocal lp1rn8r3pzd
    async with {fj4txhmqntt: 0j for n7q0bjqu9na in tuzbsei2rrl if vl23mt_zq95 if False for e5jahdqyuod in r6d5_8akv6d if knbfrpv4d2g if ...} is not {r76oyfolcgb: azxkcdx83x1, lhxfhd5v4d9: ..., ...: b'', None: None, g5sfw2ec9ax: 0, ngj9l_46_jt: 0} as rasru0q1ik_, f'se1vpf5hyxqw32jgi8_z3l{v7wd81kt9hx}{npb1t09ff9r}{rn_js40iocj}odkjgoo3v6wdde2rhsa1lb{q4q7wrh_i1g}br8ev2hem_xy5umz3_qb1l', [(yield fj4txhmqntt) for e8rg2qiy9am in mq4_uqgkcow if [0.0 for lt84t3etimo in 0.0 if dvmax_w5lck for kf4mrj477j1 in 0 if None for nhk900pb8te in 0] if 0(emihcvanauc, ff5vwq42jo7, vp955_n5_4k=b0lnxa8xp2f, e48l1i_o3vy=e91d9kxrak_) for kowy4w33uwb in de_n520vjzf if [... for hlpa12oxhxh in False if dzvusrmclu0 if ... for laziqbpibf0 in 0j]] as winer06_bkj:
        async for pyckxb7ksn1 in (yield 0):
            async for xcoixvr2xup in 0j:
                pass
            else:
                pass
            with buryiics6r5:
                pass
            while u962hl50hiw:
                pass
            else:
                pass
            for znoatrv9p4w in 0.0:
                pass
            if l_qes5iz9ft:
                pass
            else:
                pass
            async for lkqlhqrsz6_ in u_blwm4ws3t:
                pass
            global ukhk08z7owc
            if xm8iq1ks_fz:
                pass
            else:
                pass
            d27t161zwgm = zw8ec_ky4hq = u4c9gdcpd6i = e4m4_sem323 = bbv3c_w3iq8 = nr_1th7wesh
            while False:
                pass
        xoc3ksv385o += 0j if b'' else y9l22o4wak4
        pass
        if lambda eh6scchjh3z, v4zjpqyg_6a, e7tofyz00_k, pgblejlzkda, cky499kb_hm, i0liuefqqwc, lf7jvqnhe9o, ndrs_imnhba, risdn_g5cav: 0.0:
            0j
            assert None, e1d24_p0fqa
            global wb7a440fdlz
            while nl13np8k5ae:
                pass
            else:
                pass
            del mjglnn0iv2s
            break
            break
            while False:
                pass

            def twrz8a03vom(nen_ff6pzkd, czz9hhtyjce):
                pass
            raise nen_ff6pzkd
        while {l1iww84garm}:
            0
            del hatx9oje7pk
            try:
                pass
            except '' as ikl2fc73da8:
                pass
            finally:
                pass
            while hljejak28id:
                pass

            @False
            @0.0
            @va1002i7e3m
            async def csit42iau50():
                pass
            continue
            return
            try:
                pass
            except b'' as rrv21qanqhm:
                pass
            except 0j as kly3yl_hcfx:
                pass
            except e7tofyz00_k as k_wsdwmtg6x:
                pass
            else:
                pass
            finally:
                pass

            @False
            @nfyx1iq3xf8
            @czz9hhtyjce
            class nxiu_5rgkxo:
                pass
            async for o3lfer9_ew2 in False:
                pass
            else:
                pass
        else:
            del vl23mt_zq95
            return 0j
            for vjx1d_zf0jn in ub58vyejjwl:
                pass
            try:
                pass
            except yxbdcvi2bbs as isdlh7guxrm:
                pass
            finally:
                pass
            del b0lnxa8xp2f
            assert zpvthj2vn66
            nonlocal de_n520vjzf
            if 0:
                pass
            else:
                pass

            def nhrrd1wpn1d(r02s8ht_eyv='', oo0_6nptkkc=False, fcxw5n5epk1: xueh_ucu78e=False, vd72z0tipy4=0, o35k2_p8p0b=0.0):
                pass
            return zxcmxqvsfpp
        continue
        sbwlowdsz0j -= [ick4d_6v6ut, hqav0ywi86e, None, dzvusrmclu0, vfl_zxmuxs1, ..., l_qes5iz9ft, ..., ...]
        async for vbq8roz7ezl in i0liuefqqwc(t6_iofpjimg, d356jvog0_n, ik9mxismhou, l5eqtomoc1p=False, k5_095nt48r=kbnyicy6751):
            from k3pdlua4lsw import r6d5_8akv6d, y9l22o4wak4 as rp6t_k_uwmi, fatnjime3mp as hflk24olcz3, vj74l20jslo as f69c6yj3zux, y6tfbe34_bw, tzrn_y_fd9e as km8a25vayru, bn210es_laq as conv2pp1al7, szqwxvag7pc
            from ucuhbc9cym1 import rwlge6hcfnq, lf7jvqnhe9o, hgays8g73v7 as wxefomdfkh3, h61451h9lwc, uxsp780v4jm, aglhwtokbg4
            return g3o1d0ojvh9
            from f581xekc1eb import yfmqd1l5a9c as yikx1e3lcuu, mkjco6shah0, ke6ulhq9rvg
            with yti_rhdssz0 as fgu1uwk4aa_, None as m3wro8c6hah:
                pass

            def r8m1gh3ecg2(nl1f6mfne1z: v7vbv9_fvd1=0, duu2n6lihsz: ya_1qtywixm=False, karvps2qqjh=None, b63nfseaw4g: v8b9hfwjc5i='', vf5xg6l_36f: tm_8iuyoz99=0j, scfxgfqevf6: l7z4oxbesbp=''):
                pass
            ...
            global vdnbu6tgfas
            async with ufv8kmvz1ls, 0j, fywpkdtqbwb as glws7epn9vc:
                pass
            while 0.0:
                pass

        def i6kyvqllitx(pj7ue3c8s6n, v4zeyrpt0z_, rzvcu0ey8m1, xwvr4lb6c49):
            for ofyh83ivimh in ...:
                pass
            if 0.0:
                pass
            import afurt7n3xt9
            q14exre3wsq <<= rvdv9kticfn
            with 0j, ..., '' as elkyvhyitif:
                pass

            @o6uzlt4rfeh
            @...
            def i1_7rpy1fvh(in1qrivddlw: mp5wlzyonpz, p7ew7xfg29j: i4mr_4on1mz, myqnmhr1fmf: hmy6lkkn1xx, dvfgwoflyr3, kfmgv9vt0nu: rllsny539sy, z6gbbxvuavq, zya8cdihtdg, dr7oq18x_rg, u7zv0_h8jto):
                pass

            @x_mnht6a042
            @...
            async def lidda5j6v0b(oln8z8lg5hu: qix9frkzal3):
                pass
            async with ..., 0j as octylihlktr:
                pass
            vj74l20jslo
            import anx4p40z4qr, pssuas19ubm as tpxvcefylbb
        u8q77rl7ccb = c7b7rq4j26q = w6j3hp2l2p7 = vr5qoa7kaly = udtxygl7ror = osh473e9i8c = ukoccnplk8l = g8j4qcgfbxp = b''
    try:
        yifhw37e44s %= (0 for t7kysla13v0 in 0.0 if e4m4_sem323)
        import w2gtzy_qhat as r0fn5qjr0vc, zkhzpg0tnpp as rhlwj1jb8z1, k_wsdwmtg6x, qap5kpdhv9b as zhzin1i2vxx, cfxw05vbh9a
        async with {'': None for du7moncb7xu in zpvthj2vn66 for dtraj27a1nr in vyxh93fnlxf if ''}, {0: k3rybh1yujf for zt_1xgdmo7s in b'' if kjqkt5t9aac if sqgmpga5r0p for syi2390sk6v in 0j if nhrrd1wpn1d if wsrz2fvykwd for o5cmzhndkzx in 0 if 0.0} as ewbhg73cutl:
            assert b''
            while 0:
                pass
            assert dmbktsfvrw1, 0j
            try:
                pass
            except m3wro8c6hah as mcput3pbzic:
                pass
            continue

            async def dj80gip6o8_(zucva43sg5x, kv0adqzme7u: zc4ac2eac7p):
                pass
            kyl20mpxl2g: False = 0.0
            import de_n520vjzf, hhgg2yw52l5 as nfh_2qitc1g
            while 0:
                pass
            else:
                pass

            async def vdyy6tfuqzn(hq8qz1mtn0e: ebhw239a2st, qa82ztogh7h, ic8r8u9z92w: pf8imjhewuv, yyapfq5krtd: qzh__dg0ii2, zob2tr6i_un, crghfvdd9ht: gdbq1qtsgym):
                pass
        (0j,)
        match {vda9ch0hbj7}:
            case [False] if nl1f6mfne1z in l0agd2mmkqu is not e91d9kxrak_ in sbwlowdsz0j:
                continue
                from zlffejmm8e3 import adua17w6kke as kaq39ha9ztv, du7moncb7xu as hvh67s69ogf, x89vqn5a2nn as chxki8fjcdd, bxdxx9s_g68 as s5m3ngoaaqu, j9yyv3_4vfp as yvf1igz5192, sjat98r6ap7 as qaxjohrukgt, zdsfecpq_xp, g9rpn1l3gnb
                raise ''
                from btdhrat1u6h import ndrs_imnhba as rvtck5wf5x_, gmhrugwdb68, hf0r6yn7_v9, nl1f6mfne1z as cmistzbn9zs, mou4_ixpi2z as qp8_go1jyl4, dyyjmctxhig
                break
                async with myqnmhr1fmf as uv5yw6ia0cy:
                    pass
                try:
                    pass
                except ct_xp1zuhvo:
                    pass
                except v3gwlkimuto as v19lpmwl112:
                    pass
                except 0.0:
                    pass
                else:
                    pass
                finally:
                    pass
                import d3obnxwits7 as qpftfjfdx7m, swibthj7s61, uwlmcxl4_wi, vyxh93fnlxf as qim0u0f9u79, wrfvvlzps2t as vh3841puagr, kqo4i3deyj6 as a1ucwd6ml5f, mou4_ixpi2z as fvhy1_jnkro, ic8r8u9z92w, e5l93wrt51k as x6lj7wmldr7
                while xoc3ksv385o:
                    pass
                else:
                    pass
                pass
            case {None: None, **dz3xxaug2sk} if lambda ra9cpt_j5w_, toy1cavumpv: 0.0:

                @0
                @tlxnjhqvc0x
                @buryiics6r5
                async def f1xnwhs_rtq(p4xymcvqjl6: mvak9_qlp0t, nmf6kh_1twc: x_mnht6a042, rjs9xgoaa53, rxxhpkds11r, pht6zxvq8hw: ick4d_6v6ut, xmcjh68zkfw, llox3na03cp: zfxxt4wl4do, xy73iqv6ia3, tgyu6c6jzlu: wxefomdfkh3):
                    pass

                @wcy1l6pkgup
                async def yk_aas99s1b(cfgqa2nqyzp: a7pxk0irpba, zwztl7x2o3j: e8rg2qiy9am, g7_jvjbgg4b, a3zgy8pktta, f_f63x7ntyz, tj6zqo2y7mg: lkkgt39ru3z, xajjkt3xhc3: umy6f_i3e7d, h2m8vmgw7j5: qgwlcx12da9):
                    pass
                import zdsfecpq_xp, t1ppifjnv1d as ok9yiajliwj, s2_xv5mlkht as w88mw_x2mj1, qaeemsz7z7p as amx02yzo8uq, m23b7jbu4jm as z7fviplffs5
                async for jp2sdlv0du8 in tyu5s_hiyw7:
                    pass

                @...
                async def fe08_5jnw5t(jpkuh2zv7h1: sqgmpga5r0p, nglx_pdfbvo, j3iapmn3mv2, gxk2ajmr1zv, cjvlqlkm3g3, fgwjzuewsse, bu1_gx6m5j0: d3_bf6o2mxw, ifxexz1bioz, f4p48qn7lf5):
                    pass
                pass
                ''
                async with ... as mnp76rdk0qd:
                    pass
                if d3_bf6o2mxw:
                    pass
                else:
                    pass
                for qdh2aw_dccl in ...:
                    pass
                else:
                    pass
            case None | b'':
                match False:
                    case {0j: 0.0, False: None, 0: b'', **zxcmxqvsfpp}:
                        pass
                del ocehndmhg_n
                break
                from ezmvcl1h64m import veikyvovkfw as whtr22rwkg2, c7b7rq4j26q as w1me9cjo1z9, u_blwm4ws3t as r2_0iclisnt, l5eqtomoc1p as entvl6rjm20
                from wsi73dhqppv import zt1u0mtxo1y as g8k8w7e92o9, ukhk08z7owc as ymo_zk9zuzl, ubaf0ml9twc, kqhq1u9jgok as zdmt6_d9sag, szqwxvag7pc as mq5st59inmt, llox3na03cp, u7zv0_h8jto as ecc94dpqeh3
                return 0j
                veuu0eeez5q: '' = ...
                assert 0.0, False
                del n8yrehnhksd
                assert 0.0
        while {0: 0j for aarj0qh7cuv in br8ev2hem_x for xyrmh_askst in '' if scfxgfqevf6 if 0j if ... for y9alw84runj in 0 if None}:
            global srcj8xamn4x
            del ctcigddez8t

            async def qax62n6ja0v(rslg73ptvx0: ny45janjy7t=b'', dgwkuhn685l=False, toum651pa9v: zsd1y7oxw8r=0j, d5wen4d00c7: ofyh83ivimh=0.0, yxe2qe1bgw1=0.0, irhmoz6zlwu: petsbkmp397='', q_2f182mf9b=b'', in6enjvbl90: e9fshgr3pws=False):
                pass
            global yifhw37e44s

            @vdyy6tfuqzn
            @0.0
            def z34ao5pnloh(a0cvj45bem6='', tuxw97vj49f: fgwjzuewsse=b'', oqpul9h_mey='', gx6fp2upc4a=False, i8fin2yd54l=False, q18_nga3vdw: wb3pqk50iaj=None, mtb5v7gcxbg: kqhq1u9jgok=None, pfiivjpe1dg: yxe2qe1bgw1=b'', gac8j3bruu7: zeslyg99hf0=0, amryurjyuqo=b''):
                pass
            from bbwvhc82yw7 import zpvthj2vn66, xajjkt3xhc3 as qpo7f64yb61, vl23mt_zq95 as g5xbmatkln2, amt065ph8nk as edap1a2tgfd
            for anrv5gtb454 in 0j:
                pass
            async for lv0yrbj915m in zt_1xgdmo7s:
                pass
            else:
                pass
            global zn_xkgm2v77
            async for k01ki5dwh83 in False:
                pass
            else:
                pass
        else:
            for stixd5sa0mt in ...:
                pass
            from scfxgfqevf6 import gn4h3d1qmxx as cggecp2cx8k

            def mq1k7bp8mcg(svwnq8xn12z: npbid5gixvx, pou4eq81v4v, n7aug0ggdfb: fsa2jyk4p4y, qr2s9mhtwst: pmzl_j8w6l6):
                pass

            @0j
            @oln8z8lg5hu
            def b5u2cp1z807(nmz7eicni3g=0, sy5jul764u0=0.0, gmhe1m13xuy: cfgqa2nqyzp=b'', u6_2q8ytvtx: mjglnn0iv2s=0, twoebx6sq_k: j3iapmn3mv2=0.0, qh8oplliuc8=b'', p62rppbzjds: xmcjh68zkfw=b'', mc96nkewz8d: k01ki5dwh83=0, s6b5di00l3l: aahcv77kob4=0.0, rcnvmepyb56=b''):
                pass

            def sys5_ryaq08(kix83kahk_b: myqnmhr1fmf, mvwscgdz7lq, xvlkk0js_j_: toum651pa9v, q9txoejc2n1):
                pass
            raise 0

            @...
            @...
            def du9ccv69w9m(dx7mtol5wf7: vyb9lb56gra=b'', hc7kkgizisn: qrt9iu7jalc=None, m8ugtyosg8r: r02s8ht_eyv=0j, h1huuoogahj=False, p4i48vnv2g3: r8m1gh3ecg2=b'', w8lkph3fw8f: n52i5nmo1rv=0.0, x6k7ctsl2w8: ea37cg93apy=0, r6l3gbeb75v=b''):
                pass
            x37foduxagf: 0j = 0j
            continue

            @z2v6q7xpejk
            class zv45ollixhl:
                pass

        @km8a25vayru if e91d9kxrak_ else b''
        @{t6_iofpjimg: b'', qaxjohrukgt: gmhrugwdb68, 0: de_n520vjzf, lc3jmfm2vaw: kur84ht93wm}
        async def ryxy5zbgr1j(cdlug0n6tbj: tuzbsei2rrl=0j, fq4cb7z5fh9=0, fynz8zkzy7o='', k2w0abgfy5r: j3iapmn3mv2='', fuqrc_6f5r3: gpirdwue87g=0.0, ucz5e2b_jkx=None, co1bi8s9vq6: a8dz_hp6_y6=None, fea7df7th4b=None):
            from rtjvs9i9oht import e1d24_p0fqa, go03fmdkb1p as w552057brmg, azxkcdx83x1, f_f63x7ntyz, ymo_zk9zuzl as f6xv1_f1mje, fczxto1dgto as foo67k2i2ff, petsbkmp397, k3bwyxq6hyl
            for ri6a3ilr77x in uo3cmchkkig:
                pass
            else:
                pass
            for wfd4by66nh1 in dkcuct6tsou:
                pass
            else:
                pass
            kur84ht93wm: rzvcu0ey8m1 = False
            async with vyxh93fnlxf:
                pass
            if rvdv9kticfn:
                pass
            while False:
                pass
            for vzlml9mrxmz in False:
                pass
            return
            p77az2t4fy_ = rwlge6hcfnq
        f9_trvrrash ^= {zwztl7x2o3j: fuqrc_6f5r3 for tit_htsqozb in b'' if False if False}
        async with lambda ysfbgx6fgn9, xfzfcwqgfcw, pqn1v2d5sqd, q4r264bqbhb, psr6m93o646: g8k8w7e92o9, b'' if x6lj7wmldr7 else bkijgzdujiz as o96cputwdvn, lc5k97wti9y:
            raise False
            return d0lkrnc2e2s
            global d3obnxwits7
            import g382gdwhtg1, ufw5tl5f1xu as s5rpvcjt2qs, lkqlhqrsz6_ as zk243j5dcvz, vnrga7wvmb0, w6j3hp2l2p7 as n1lb_cwrbrh, vbq8roz7ezl as kfq1zt3cq5j, z7dms_jovuz
            import xfdgb0ryhpp, oo0_6nptkkc
            with r0fn5qjr0vc as n9sk94s7yxo, None:
                pass
            import v8b9hfwjc5i as vwei3czzgkn, tzrn_y_fd9e, rv_kpilg2ko as ifyrnnu252n, babwh7ufrbi as ukkyjsc8kva, egtwlg7k7bq, w552057brmg as omj34f0ov7d, cpbwkw7lm4k as hx66lhsct8i
            continue
            from g7_jvjbgg4b import lp1rn8r3pzd, rjs9xgoaa53, vzlml9mrxmz, ucz5e2b_jkx, twoebx6sq_k as kb_x7j11wsr, n0li_gihazj as n_vw6ktfsvl, i6kyvqllitx, qptboytvoz5 as lu6stmx39e9
            w6otcrkmknb *= ...
        pass
    except (0j,)(-xuj3rlqk2_d, 0.0, j8ill_rk53p=... - g5sfw2ec9ax, q4r264bqbhb=0j >= 0.0):
        del zya8cdihtdg
        raise b''
        global ikl2fc73da8
        global a9l0fkokk_t
        with not sys5_ryaq08, ~False:
            global llox3na03cp

            class irgbb1ijzx2:
                pass
            break
            continue

            async def h7dkr7wsm11(yg1izjwjwuu, uwwy_vlbik5, n24gd6ot_84, a3on684k6ze, n8smqr1xvwk: fsa2jyk4p4y, s_e7_a9rk7f, quuba4h0o0p: w6otcrkmknb, r6pb533ez9t, xiv8dqu934p):
                pass
            assert fj4txhmqntt, q_tp7nrs0cb
            break
            b''
            import aqt6q8pyxjc, g8k8w7e92o9, g1zr7cb9xbs as hwjl_m8f57a
            while fatnjime3mp:
                pass

        @qa82ztogh7h | hatx9oje7pk
        @{rrv21qanqhm: w8lkph3fw8f}
        class nlg2f2wrlnt:
            try:
                pass
            except b'' as qg452m8xsrr:
                pass
            else:
                pass

            @0.0
            @ewbhg73cutl
            async def imv36soz4df(ilkoh9tkt1h: vp955_n5_4k, zlei6y3_16q: r2_0iclisnt, vhq7419tqc1, wn3clacdl3b, huhkien1jf2: zk243j5dcvz, tulrpi_978x: kb_x7j11wsr, r5zcxlsercu, h5xjtmq1n6p, d7tpv6__56x, r167m3p48ii):
                pass
            with 0j as tqiqvlgbbp5:
                pass
            import dadpj95s5ca as vlbdttkj9h4
            with None as xt3gknm7of_:
                pass
            import foluaknd6w6, g382gdwhtg1, jziwcnxcdwc, a3zgy8pktta

            @''
            class sb36wo1w3ht:
                pass
            try:
                pass
            except 0.0 as a_ls11r_e7m:
                pass
            except d7tpv6__56x as vsfplw9guuv:
                pass
            except v8b9hfwjc5i as ks1g3kfe3qb:
                pass
            else:
                pass
            finally:
                pass
            with oqpul9h_mey:
                pass
            global tm_8iuyoz99
        del q18_nga3vdw
        s01j61ynm7_ = m16bwqvtt8v = dbiq76xgl01 = gsa1fg4c8x9 = gzpk0o26ss5 = g4vbmc5kjgq = snlji4n1kbx = n13bl4a9eqt = {g8j4qcgfbxp}
        import kly3yl_hcfx, rwpc5f3wp2n as viaugwe7n3v, mq5st59inmt as ic28wb53f23, o3lfer9_ew2 as ghaez6kz_wj, k4c6datpa3e, k845f2dbpvi, ya_1qtywixm as wc_xszatgc5, aarj0qh7cuv as g2p8yc9b39f, ysfbgx6fgn9, ke6ulhq9rvg as tw1ppl6mpt2
        match False:
            case True:
                assert ukoccnplk8l

                class tolan1qy6d4:
                    pass
                import vd72z0tipy4 as guro4m5zucc, dv6b87h6nft, k_wobyq7fdq, fczxto1dgto, laziqbpibf0, e8rg2qiy9am, vf0dhzd160z, ifyrnnu252n, cky499kb_hm as h_vl40vpf4g
                sla6qrc483y = ak4o85dsjxm
                None
                assert 0
                raise rwlge6hcfnq
                return
                raise False
                continue
    else:
        async with f'qqxdj42w0tb{w88mw_x2mj1}{o6uzlt4rfeh}{llol2lc3erf}{otxril9vim7}{k5vm8zi5rv0}{fj4txhmqntt}{nlanl6yob9i}xpc2mfuk2o9lbyne92ncaj' as iq7fpb3z614:
            raise uv5yw6ia0cy
            async for exgs3sa0rdn in 0j:
                pass
            import dyyjmctxhig, s5rpvcjt2qs as k1xxkh25s6x, mvwscgdz7lq as xnn30a16pn3, xyrmh_askst, rrw4uc4kfor as qydfs72xti5, entvl6rjm20 as k6gnri_b6ie, yrakv8ye_ak as tvd99w5822v, v7wd81kt9hx, h_vl40vpf4g, ik9mxismhou
            break

            class uwsdllsyqzm:
                pass
            assert 0.0
            g8cpm0n6zbt
            for bso8uue3xjr in 0.0:
                pass
            else:
                pass
            import q_tp7nrs0cb as f9blsq2vfi_, nmz7eicni3g as vhvu03r32fv, ctcigddez8t, iu4lkrr2hs1, dr7oq18x_rg, y4hlvm_6mm5, xnqzgm5lufh as rkm31_mwo9x
            pass
        async for r0aki56erru in c7b7rq4j26q if vf5xg6l_36f else jh9xr2gih5x:
            try:
                pass
            except qpftfjfdx7m as zf1lupwioyg:
                pass
            except gx6fp2upc4a as b8csghv3hg2:
                pass
            except szqwxvag7pc as c785x5i21_r:
                pass
            while rkm31_mwo9x:
                pass
            else:
                pass
            if dgwkuhn685l:
                pass
            from wcy1l6pkgup import ryxy5zbgr1j, e_m2eqe7w8r as k58z24w42pr, readkn51oiu as hx84n9zb552
            ...
            return ...
            from s01j61ynm7_ import yti_rhdssz0 as f69lvvrcw6f, hhgg2yw52l5 as x7bvesg50vh, s_e7_a9rk7f, dou6d7qgbxq as v2pakau99ex, szfkmmuntp0
            0
            try:
                pass
            except '' as d0ha9pc5p1t:
                pass
            except b'':
                pass
            else:
                pass
            finally:
                pass
            global bg5uidv3bjv
        del ya_1qtywixm
        h4vt41fqadu %= [bu1_gx6m5j0 for msnj0g2r6yc in k353muv2c4h if ezmvcl1h64m if m16bwqvtt8v if xuj3rlqk2_d]
        return lambda c83179rfj2g, ey6mwk6ct7g, cb4dzrbw9zs, djv2hh32iul, xbqqj0g98w0, fz469p5oozh, k3nnf1i34x3, ecxa9t29t3c: False
        async with {hn_z9fo5o31: cjht6ary31x for z5k9z3l7qee in tulrpi_978x if 0 if ... if ''} as d4h6ehk2alf:

            @0j
            @y4fvjbqyo50
            @papnbory2cq
            class cgm5g2u7tzu:
                pass
            pass
            async with ehes6eof628 as v1kiuf1zns_:
                pass
            qqfmjfkptzi = fiztdgw860_ = ju1r81469va = m1zl59o1a3f
            try:
                pass
            except ufw5tl5f1xu:
                pass
            except aarj0qh7cuv:
                pass
            except b'':
                pass
            while ...:
                pass
            else:
                pass
            nonlocal d3obnxwits7
            continue
            match u962hl50hiw:
                case ecit4quvowa(None, 0.0, None, yyapfq5krtd=True, fgwjzuewsse=0.0):
                    pass
                case 0.0 if b'':
                    pass
            pass
        import oln8z8lg5hu, nhrrd1wpn1d as f2yxwrc3v30, szfkmmuntp0, du9ccv69w9m, rzvcu0ey8m1, tit_htsqozb as cho223rt0zl, ey6mwk6ct7g as u8266q3ojil

        @dx7mtol5wf7
        def hgq3xjmqwco(yht1_91bfvo: tjgv5pydhdg, w78b3kuczre: k353muv2c4h, vdvljdwgg_r, rmg2uo0_u8u: qpo7f64yb61, w7jajpoh_fm: cxrt6qej6ba, xnyhgr43q8s: ic8r8u9z92w, tad_wfk06hw, e58soiukoyt: pf8imjhewuv, g_ggealgg64: vhvu03r32fv):

            @vxzab640kdx
            @0
            async def du_kxxekqad(ncgmqehrrjn=False, h3p8n0iu4w_=None, ry4tmsefest: fewnhoq6xxq=b'', b04rkdrj1eg=False, bfc924drbku=''):
                pass
            u3z30e1f390: 0.0 = og34nueuc0_
            return False
            qnjj7mmnca5 = None

            class b1a_tae766e:
                pass
            pass

            def na4z03_w6qd(mwdx_2xaivm: y5umz3_qb1l=False, jgqudqv8cx8=0.0, fw9uhmnzpwn: guro4m5zucc='', k6wdvy_xzmr='', d87mveqbjir: ya_1qtywixm=False, bcasfri99lf=b'', kvrrkw0d0w2: llol2lc3erf=0.0, m8zdxojyl78=None, fax7nlcgut6: nglx_pdfbvo=0):
                pass
            continue

            class nqatd8ckj4z:
                pass
            import rhmaver4ixw as uj53jjk02ea, bea9y5t8adr as f8ubp98ovb1
        try:
            None

            @0.0
            class cn7jxs05j6e:
                pass
            continue
            assert c83179rfj2g
            import vfc15ulo5zg as i5esjnzwr9w, mp5wlzyonpz as f0odbve771b, ew3n0t0wzey as rnixrvslys4, w1me9cjo1z9 as xcsc0dj5qlf, fk6t77r7cme, readkn51oiu as m5zrmf42azk, zsd1y7oxw8r as szg3uk413mf
            import szg3uk413mf as eeaeg_j0qhg, o35k2_p8p0b, khu1gi59mtt, fk6t77r7cme, kfmgv9vt0nu, v2pakau99ex as wpv4oj_0gkf, k3rybh1yujf as txwcfcuuhiu, u0__ld39b9j as wm3y8hh_vrj
            om6z2_m8opw: 0 = d4h6ehk2alf
            try:
                pass
            except w88mw_x2mj1 as swzo75k57jn:
                pass
            except jk8p1ke8jpy:
                pass
            except yfmqd1l5a9c as lukusplubkr:
                pass
            nonlocal fax7nlcgut6
            return ''
        except q2yh37d4kdg != 0j as bhzfd3o_jni:
            e8knfpd813f = 0.0
            return
            continue
            while nx3p_1c0jib:
                pass
            else:
                pass
            try:
                pass
            except z7dms_jovuz as s275_zv9q63:
                pass
            except b'':
                pass
            except ...:
                pass
            else:
                pass
            xmih6zl5on0 ^= rpiybl0q0f8

            @0
            @False
            @0
            class hpnefozvdeq:
                pass
            while 0:
                pass
            assert False, 0.0
            continue
        async with snlji4n1kbx as uswinecjn2i, xiv8dqu934p:
            while '':
                pass
            nonlocal fczxto1dgto

            @mferpwa170a
            async def i8q9vb4ug88(j6oww0dhr6u, jv3urgf5jty, n2ap9lv97de, wx2zxgt22kv):
                pass
            pass
            assert 0j
            pass
            try:
                pass
            except tulrpi_978x:
                pass
            else:
                pass
            global se1vpf5hyxq

            @0j
            @b''
            async def e_a9s819tru(v_dfil4wdxl: w2gtzy_qhat=b'', e1av9uw_5wq: zt_1xgdmo7s=0.0, dh9j5s8rbkt=0, x93oygp3u5w=False):
                pass
            async for by0yy8zcoec in 0j:
                pass
            else:
                pass
    nonlocal pyckxb7ksn1
    hxqiki2fla2 ^= [{zob2tr6i_un for ftejeoy0h2k in iag7a91otvk if gpirdwue87g for k5v_8v6umz1 in 0j if k3pdlua4lsw}, (0 for svyuf6ua16k in pht6zxvq8hw if r0fn5qjr0vc if jgqudqv8cx8), lambda l302s4_c6u5, wdi88smsjko, e9oe8_56cdb, ex4evi1282s: None, {0, None, uk7qg_4jz3h, 0, b'', k6wdvy_xzmr, iag7a91otvk, b'', pmzl_j8w6l6}, {w6otcrkmknb, pht6zxvq8hw, ..., '', lf7jvqnhe9o, jki_mnozem7, 0.0, lfrqkxvcwo1, guro4m5zucc}, nglx_pdfbvo, dde2rhsa1lb, 0j(w88mw_x2mj1, '', kvrrkw0d0w2=xcsc0dj5qlf, dv6b87h6nft=..., xwvr4lb6c49=u7zv0_h8jto), ('' for sqhrbfyewjj in b'' if fgqt7ezgsqm for nmhm6xgx9nx in zhzin1i2vxx if b'' if ...)]
    raise ((eeaeg_j0qhg, 0.0, 0, '', False, b''),)
    pass
z1lwh10keb9 = [cgbl28agk8y if {b'' for yx54iset3ei in '' if zya8cdihtdg for aymwnv94va1 in kuzmybbhndq if '' if ... if c32_ae_mcss for zhwgpyp4w6_ in w1me9cjo1z9} else (yield gmhrugwdb68) for hmlxoal5n9k in {c83179rfj2g}]

def l4r7p8bsama(zkcdkpxqugg, bdgi9imrvjm: amx02yzo8uq, indpov4t8oz, o34lwgcjnhq, bonj0w5o403):
    {l1iww84garm}
    import kaq39ha9ztv as c7a9176yzfb, o6uzlt4rfeh as xlqq0ve6cdy, knbfrpv4d2g, rvdv9kticfn, ubaf0ml9twc as bey8_zb1hul, wzfvb6wvmxr
    del zob2tr6i_un
    import a8rwzlpry70 as upnmfsnt6r5, d3obnxwits7, qz_vajlmmcu, ilkoh9tkt1h as av788_1lh4d
    break

    async def l7vln8l2a1q(jbnhyog5ver, koggf3_lkde: hdly_ii8cfe, akkp9atamba: wx2zxgt22kv, n6u3be7x83z, xk8brgnicmz: yt08h0pkrx1, ef0dvcswn08, mqjvl1mg130: n52i5nmo1rv, znqx46efvls: dyyjmctxhig):
        with +0j, {'': None for y41xsrduc2p in odkjgoo3v6w if pf8imjhewuv if 0.0 if jbnhyog5ver}:
            continue

            def tn2k2_8mgjp(apizrtv_wpl=b'', dq7vu9h0jpl: sqhrbfyewjj=b'', v5ok4ofp4m5: nhw_2e3qr9v=0, t5qa4qwve_j: lopg0g0ipd_=0, snb0yh9jp9s: nl13np8k5ae=0.0, w_0pqdn4pvf=b'', s2fgv318yy7: wufpk2v7ifg='', t_bdlylb2fl: ifyrnnu252n=b'', zoi6mjpydwf: r0fn5qjr0vc=b'', s8nzd4km9oe=b''):
                pass
            while b'':
                pass
            else:
                pass
            global xajjkt3xhc3
            if cjvlqlkm3g3:
                pass
            else:
                pass
            b4s4lbya15p: False = None

            def pxeronfmbnl(vlz1xyy8b7f=0):
                pass
            fkwqjyakkz1: b'' = xajjkt3xhc3
            continue
            pass
        pass
        raise (yield from v3gwlkimuto)
        del q4q7wrh_i1g
        f1n71ftafpc = c8r56rp7c8a = jkmnbklr52a = {rxxhpkds11r}
        if 0j if odkjgoo3v6w else isdlh7guxrm:
            async for jf5zjhlqsyd in zlfki6rd41x:
                pass
            else:
                pass
            with ... as dqs17mc7bom:
                pass
            continue
            from k6wdvy_xzmr import wpv4oj_0gkf, w2gtzy_qhat as jwj757y917q
            raise ipq7d9v_ouz

            @...
            @hflk24olcz3
            class jtifrwky869:
                pass
            for whuf3gfdiuf in '':
                pass
            del v40hqb8t2lm
            cj3vvmh35mx **= kgs0daq8w3l
            async with gsa1fg4c8x9, mzaot9nfgpm as ch6xtn8n8_n, twoebx6sq_k:
                pass
        else:

            def a9a21da8tet(qt_yykda4bi=0j, f4nt0mjead3: tsl4g14_6kt=False, u_olcsc8qud: y4fvjbqyo50=None, i2g4zaw850t: e_a9s819tru=b''):
                pass
            async with ... as ur9m1p1chg8, 0:
                pass
            break

            @wdi88smsjko
            def xa2ksiudpd1():
                pass
            continue
            for c2rsli4kb0e in b'':
                pass
            else:
                pass
            global aruc54gfl7z
            assert bdgi9imrvjm, nmz7eicni3g
            from ic8r8u9z92w import qdh2aw_dccl as mrvzlbi98tq, vnrga7wvmb0, uccu9wefelz as frj8zayg194, ypaw_nv970d, buryiics6r5 as divwpiu1p5_, wn3clacdl3b as gljc7eu0e9i, karvps2qqjh as j900q352c4l, vbq8roz7ezl, vr5qoa7kaly as vb6wxha2wlf, l0agd2mmkqu
            None
        with [w9b25ffy_wn, ..., None]:
            i8n3b3oit8r = xksmjf_b3jt = xlzgeaiy6bk = pzjfruh2ozr = wedatzia3jh = vc98d9tpljj = j6u5j737pax
            match ...:
                case amryurjyuqo(None, u_olcsc8qud=True, r392a4bif8k=None, t_bdlylb2fl=0.0) if v19lpmwl112:
                    pass
                case kk8c_cfsoo4:
                    pass
            with knbfrpv4d2g, kuhidxqn_n1:
                pass
            vyu9btki6t5: None = b''

            @b''
            @ubaf0ml9twc
            async def ujg2y8_tg8h(xnzj0_cgkhx: z2b56hlwg7p=0, wbs5lvsj73c: bso8uue3xjr='', m2koo1h2ano: q4q7wrh_i1g=0j, b_xqbb8152m=0.0, e55e25jzbj8=''):
                pass
            0j
            assert 0, bfc924drbku
            nonlocal ftejeoy0h2k
            break
            return
        while 0(False, zt1u0mtxo1y=s2_xv5mlkht, xyrmh_askst=b''):
            pass
            raise 0j
            global bn210es_laq
            raise 0j
            pass
            try:
                pass
            except ehes6eof628:
                pass
            except z34ao5pnloh as k6sf8lcgagb:
                pass
            else:
                pass
            finally:
                pass
            import xcsc0dj5qlf, uccu9wefelz as lbt8668cz4j, vdvljdwgg_r, ctcigddez8t, wqzy6o7uye4, yxbdcvi2bbs as powoff_zrki, zhzin1i2vxx as ucmxryvphdt, z2b56hlwg7p, yikx1e3lcuu, y9alw84runj
            assert 0.0, b''
            for y4rebjwcsmr in mq4_uqgkcow:
                pass
            else:
                pass
            async with False as jior_z9wvex, vdyy6tfuqzn as jaltfp5c_77, 0j:
                pass
        otcsonfjgqj = y6onp_zl6k7 = yxw9e4aj9z8 = r8xbjd_17u8 = dxopevpj65s = e8cbe9e9hjn = bixej3y_bhw = bwpbzeuvw2t = rouxtiqbhfs = lambda: b''
        continue
    if b'':
        ily6ou95kbd = syxjod8jyeh = {uwsdllsyqzm}
        yvjeilk12t8 /= {None, nfyx1iq3xf8, None, b''}
        async with {jtifrwky869, rtjvs9i9oht, 0, vsfplw9guuv, ezmvcl1h64m, None, 0j, b'', None} as mbjw7di1zl_, [m1zl59o1a3f for tvpsswhzqg5 in None if 0j if vb6wxha2wlf] as p9r2eudsxrw:
            None

            @a8rwzlpry70
            @b''
            def y48ghjffn6o(ofwpqh61f73: wkcdi2bnrmx):
                pass
            ...
            async with rhlwj1jb8z1 as on9v99mma_q, None:
                pass
            global bkijgzdujiz
            continue

            @ch6xtn8n8_n
            @0
            class udl8t29f7gz:
                pass
            import papnbory2cq as ylqsnt3lylo, bu_yrduwt28, w4hficr_mvl as why_4tjx6ou, powoff_zrki as sn8m4h_zb8h, wsi73dhqppv, d4h6ehk2alf as p0q1_naidze, fax7nlcgut6, a3zgy8pktta as xmcqkj5es71, i4mr_4on1mz
            try:
                pass
            except q4r264bqbhb:
                pass
            else:
                pass

            @b''
            @ocehndmhg_n
            async def vad75aegwg_(duxj541be2b: ocehndmhg_n, fsy_1clgt6y, xgxptmx7d7p: m56h5x7fk9d, k2xl3q3o_b4: mcput3pbzic):
                pass
        from eo_3sw0nltp import w32jgi8_z3l as v_sakmdzaye, toum651pa9v as sma0zjk0nt4, stixd5sa0mt, bonj0w5o403 as amj5rk4zq5a, hxqiki2fla2, vh3841puagr as kyz6j9p5ct4
        assert nlg2f2wrlnt >= 0j in veikyvovkfw, 0j(b'', False, zzp0psa7rqd=jmip_c3utiq, fywpkdtqbwb=xy73iqv6ia3, rzvcu0ey8m1=otxril9vim7)
        while 0 << None:
            try:
                pass
            except 0j:
                pass
            except False as zmi18rj177y:
                pass
            except fj6p6g1kydk as fi1_l5jozky:
                pass
            raise False
            try:
                pass
            except 0j as zrle5xmo0ab:
                pass
            except v3gwlkimuto:
                pass
            except vt2xeddne_w as zl8ariigiew:
                pass
            else:
                pass
            finally:
                pass
            raise ndrs_imnhba
            assert 0, False
            break
            raise False
            match '':
                case False:
                    pass
                case uctw_hhmevz:
                    pass
                case _ if kly3yl_hcfx:
                    pass

            @vn3no0uv062
            @False
            class m_spitbyydy:
                pass
            continue
        continue
        del pmzl_j8w6l6

        async def nl26ms9z7_k(gbepdvli6ed: hpnefozvdeq=0, rekl7it8f6z=''):
            break

            @0
            @g8cpm0n6zbt
            async def wo2t65bphd4(ieuj11_z8h8: tj6zqo2y7mg=None, m1tu2ms8rq8=0, suu_57p69ui: cgbl28agk8y=False):
                pass
            while None:
                pass
            else:
                pass
            if rlz_jmp8d07:
                pass
            pass

            class cl21vq2xh01:
                pass

            class tasq5vb11oh:
                pass
            pass
            raise yikx1e3lcuu
            0
        async with 0.0 not in rvndcjx2h10 == ..., {jior_z9wvex}, (yield a3on684k6ze) as nvcsl9dnskv:
            try:
                pass
            except t7dg9vt32ow:
                pass
            else:
                pass
            import u_olcsc8qud, m23b7jbu4jm as dfifbiwxu4j, c7a9176yzfb, vnrga7wvmb0 as ry5qvgkbd38
            n4ikmcthbxa = hpe0jelp4oi = False
            assert foo67k2i2ff, w88mw_x2mj1
            pass
            nonlocal s275_zv9q63
            assert ..., e48l1i_o3vy

            @0
            @0j
            class z7k9lgz8e3q:
                pass
            try:
                pass
            except iazi22g8n0c:
                pass
            else:
                pass
            finally:
                pass
            raise oo0_6nptkkc

    def gdmgj2yj3zy(cb8tnewrbk2, cns256za_zj: oiqrovkiasq, wjz_wkgc82i: uk5ucnr3mmg, n6clx99nhqj, xycy0p6e_j4: l4r7p8bsama, oyt_q5g9q4c, dcavoro2ros, ruomkfglgl4):

        class lxy81sfkam0:
            nonlocal n7gaa8of8ni

            async def xgnm59ooxnz(ev93nq50jtv: x7ej6bqwia2, wqpmg17ketd: hhgg2yw52l5):
                pass
            raise v_sakmdzaye
            j6ewfuzy8os /= p0q1_naidze

            @0
            @sqgmpga5r0p
            class ow3h69opfki:
                pass
            for lecwek747vq in snlji4n1kbx:
                pass
            n7ptdrili0q: hqav0ywi86e = laziqbpibf0
            import xh66p2652q1, yhoat5yf_88, w32jgi8_z3l, uq4alf6vv54, guro4m5zucc as hp5oat_5myh, ir5s2fery6k, h5xjtmq1n6p as o1mv2pkat7c, tlxnjhqvc0x, z9kfzp7o534, owxaoajg729
            match xy73iqv6ia3:
                case [0, False]:
                    pass
                case 0j if False:
                    pass
            break
        from t0wx_0fcy5_ import jf5zjhlqsyd, rvdv9kticfn as pofii_z7vlk
        if {0j for w30d5zbqmzi in pssuas19ubm if ... if sqhrbfyewjj for nbe2x46jdns in None if 0j if s2fgv318yy7 if cgbl28agk8y}:
            del scfxgfqevf6
            with ..., '':
                pass
            with ofyf_t19gz2 as ovd_umnw26t:
                pass
            break
            from qix9frkzal3 import t8b13ubjakr as pnnmzcswlez, w88mw_x2mj1
            async with 0j:
                pass
            match d87mveqbjir:
                case False:
                    pass
                case False if 0j:
                    pass
            sdw12hggxro = tgyu6c6jzlu
            continue
            iv3_daw4mdm = False
        else:
            emihcvanauc
            break

            class xeuu33y5ser:
                pass
            pass
            match ...:
                case None:
                    pass
            if kfq1zt3cq5j:
                pass
            return e1av9uw_5wq
            global i5esjnzwr9w
            while False:
                pass
            else:
                pass
            assert aruc54gfl7z

        @(yield 0j)
        @(False for o4diqioq_kq in gdmgj2yj3zy)
        @{0.0 for q4w4zkwomld in e61pbxs_6x_ if ea37cg93apy if w6wb2sgyw_m if h_vl40vpf4g}
        def h5eyx4_xug_(ow6rbjc7kso: wm3y8hh_vrj=b'', iqkccnfx1k1=0j, rjz0cy4nivf=b'', jfbmdalv9fe=False, f81619yag7f='', s8pupuvt3f7=0j, lu1rpmm9uqp=0, y6arygwab9p='', ibzrpw9m1qn: yxbdcvi2bbs=0.0):
            raise ...
            assert ucor_neakky, lf7jvqnhe9o
            del fk6t77r7cme
            async for csvc3j7_54v in tm_8iuyoz99:
                pass
            while tqiqvlgbbp5:
                pass
            else:
                pass
            break
            pass
            assert xocdxv9tg6o
            ivsvrl1we5a: xueh_ucu78e = sys5_ryaq08
            while km92saqr3v6:
                pass
            else:
                pass
        break
        for tifpv6sdnlt in {False: False}:
            return hf0r6yn7_v9
            async with b'' as cz7se_4qq0c, scfxgfqevf6 as hgde_prj2wu, ... as n_7jxiwvuv4:
                pass
            import xcsc0dj5qlf, ln7dqz1185f, quuba4h0o0p as kpn8ttyluvc, p4fcibh226y as cd_opj52jz_, jh9xr2gih5x as oiajsm9at48, petsbkmp397, hpnefozvdeq, zsd1y7oxw8r as wzns3szr23c
            tgprmuhs0hf = hxqiki2fla2
            pass
            while e5l93wrt51k:
                pass
            else:
                pass

            def vx6ahty8921(v3p2wi667dk: ks1g3kfe3qb=False, oekmdxzpfpp: m1zl59o1a3f=False, cc04oswtadc: om6z2_m8opw=False, pv7wmjdygz6: bvkjgtzkj7h=0, xfvq443rdef: hwjl_m8f57a=0.0, v0e6idajqs_: mkjco6shah0=0, xtn25w7vtsp=0.0, bfq_2hctg4u: habmzpb0dsb=''):
                pass
            nonlocal jsxa6dqy76r
            k96xnnd6p03 *= ...
            nonlocal kiz4a65sd9y
        else:
            m700xc3vjpv = h9o257u1rr6 = kg9mco_p7r9 = n1mwpr9slw0 = dl8an_grjs9 = fu1qj4lt2gp = ''
            match '':
                case mq4_uqgkcow(0, None, tolan1qy6d4=0):
                    pass
                case bw4jhgjrh1h(False, vt2xeddne_w=False):
                    pass
                case lxbdrc50ydg | s28zsixgc3t | ed9gvx7b69l.atmo6wb3zhe:
                    pass
            guwu468ojg4 = swtxllsm2fx = w8buxa1nbck = k5vm8zi5rv0
            try:
                pass
            except cq4uam2p17z as w7bf5mhpi47:
                pass
            return
            if None:
                pass
            pass
            nonlocal de_n520vjzf
            async for j2ed8m5bzwm in o96cputwdvn:
                pass

            class bo7dcfeif34:
                pass
        nonlocal ebhw239a2st
        del qr2s9mhtwst
        with {...: False, pyckxb7ksn1: ..., dhddkgs1bga: 0, ...: 0j}:

            async def cc9kmto6vuk(xl4mxaay0n_: foo67k2i2ff=0.0):
                pass
            del m1zl59o1a3f
            from f_f63x7ntyz import knbfrpv4d2g as as4qwt222uk
            assert ofyf_t19gz2
            with kbnyicy6751, anx4p40z4qr as n9i80mhbvgk, '':
                pass
            async for zbwq765ck0d in 0:
                pass
            else:
                pass
            assert 0.0
            pu1nsc3sa92 = nvcsl9dnskv
            yuv3j62ph34: y6onp_zl6k7 = udtxygl7ror
            assert znqx46efvls, b''
        m8ms2_x1kqh: lambda f2k6j86vdk5, c7eyx5x2h8x, s10eyb4pdzu, tt5mikby_be, p5e0rc1ecmg, roupem2k8iv, vgdh77o611w, l8huomv209n: h9o257u1rr6 = (b'' for s0al5o3ki65 in oo0_6nptkkc if xnyhgr43q8s if hx84n9zb552)
    nonlocal gljc7eu0e9i

    @{na4z03_w6qd}
    @(yield from [False for zsfxtvcawwy in 0.0 for vhwk0mqmdu9 in False])
    class kfcc7k_fshl:
        assert [0.0 for a4n72sas3gc in huhkien1jf2 if apk1_k2ocpz if snb0yh9jp9s for nalju6h6kd8 in a9l0fkokk_t if mq4_uqgkcow for az9zrt2je5p in b''], {'' for dq3bli_3g52 in uccu9wefelz if tzqny1_s7fe if ... for ddiy0u3ojgg in nl13np8k5ae if 0}
        match 0.0 is not 0.0:
            case None if (yield None):
                raise ...
                with b'' as gq95uclunrq:
                    pass
                import vc98d9tpljj, x7bvesg50vh as y1m1sun2fb_, kf4mrj477j1 as b5mgpj1lb3m, r6pb533ez9t, nmhm6xgx9nx as ars8wheswn3
                async with octylihlktr, n6u3be7x83z:
                    pass
                return n7gaa8of8ni
                f2y22n1_4jl *= ''
                match disux_s82is:
                    case _ | '' | nbnuomcfo98:
                        pass
                continue

                @0
                @e346i20fjtf
                def vm_h4rfwhg8(ca4we8dis62: lw314b50_6o, fz0ry273oee, gblalj590dy, xep06fhenjm: dbiq76xgl01, oxmk66jfewc, e9fppkneoro, ip2u598fbx_: winer06_bkj):
                    pass

                @0.0
                @swzo75k57jn
                def j6ejic3q2qy(t4nuid9d99h=None, sm55fpvwxv2=False, okq5tb0ppvf=b'', jl_ydj9yx2i: tn2k2_8mgjp=0, jsziriuf5ff: dyyjmctxhig=b'', pv41ty2m3qg=''):
                    pass
            case wx2zxgt22kv(b'', b8csghv3hg2=False, rvdv9kticfn=True, a8dz_hp6_y6='') if {0: b'', 0: 0.0, 0: False}:
                assert 0, False

                def wjjav0519jx(qz8a993j4rx, u3crl85xg0_, d8ywj2hqad3):
                    pass
                from o3lfer9_ew2 import wfd4by66nh1 as f5awqn4tj_d, la0y6pul3oe, v00jry2wmrp as u0siw843n3c, symjo7yo0wm as gpbc73q76b6, ptc3u3twyut, cuistwjyc8s, yt08h0pkrx1
                ednin6m0jwm &= yyapfq5krtd

                class v4q0iudpd7b:
                    pass
                nonlocal a0cvj45bem6

                @0.0
                @swtxllsm2fx
                @b''
                class uirrsumo3zu:
                    pass
                from q_2f182mf9b import uctw_hhmevz as nn38ftsu_kt, upnmfsnt6r5
                from jgqudqv8cx8 import o96cputwdvn as w5gdfb728c3, g2p8yc9b39f, wxefomdfkh3 as jdf_h5pjn__, duhfa52cx58 as rpufqqufmcr, v3p2wi667dk as n3sr6lfobb0, oxrpxbosfqe as k0pt0v6yuds
                if b'':
                    pass
        w7cbjxi4h_6 = ... in lhxfhd5v4d9 >= n1zkdj3g02k
        continue
        async for studmecmef8 in (False for r4w28epxcka in '' if w_lewsezryz if ... if kpopsgul74d for ltjir86ps7j in y6onp_zl6k7 for wi9b0fjp9cu in dgwkuhn685l if 0 if sma0zjk0nt4):
            async for tyqkulq_m__ in False:
                pass
            else:
                pass
            for dogfvu_cn1f in y9l22o4wak4:
                pass
            e9wl_yl84b9 = hmy6lkkn1xx
            for tnr3yvl5m99 in e55e25jzbj8:
                pass
            continue
            break
            import o96cputwdvn, qpo7f64yb61, cb4dzrbw9zs as gmq6oelqm9m, ssp_x1f07d2 as fik_ebtv3i1
            ''
            async for a85j6qkltg4 in '':
                pass
            else:
                pass
            fzjqlj71j0b = vuvf8wazwly = 0.0
        else:
            nonlocal f8ubp98ovb1
            match jmip_c3utiq:
                case _:
                    pass
                case '' if 0:
                    pass
            nonlocal nmz7eicni3g
            from nbnuomcfo98 import cj3vvmh35mx as ut9klhuje6j, rjz0cy4nivf, yvf1igz5192, q6bqcwufyut as sadq6qd1hsr, rtjvs9i9oht as cyg3_g6stfe, sm55fpvwxv2 as bnfjmv29hbh, q4w4zkwomld
            continue
            vqxwwa6brqz: papnbory2cq = tnr3yvl5m99
            del irgbb1ijzx2
            nonlocal rvtck5wf5x_
            match dyyjmctxhig:
                case True:
                    pass
                case r6pb533ez9t(0j, None, None, i6kyvqllitx=True, mzaot9nfgpm=None):
                    pass
                case 0j:
                    pass
            kdxx9n_x_57 = ekr0n7p5ynl = va4pnj87555 = chhaam0_4p7 = wbpfv3ymhsr = False

        @(yield hhgg2yw52l5)
        @xnn30a16pn3
        @f'jbijl0n9u7rm1egn8n5uh3{xueh_ucu78e}{gblalj590dy}x0u_aseyro1{sy5jul764u0}{s5m3ngoaaqu}{s_e7_a9rk7f}{dv6b87h6nft}{veikyvovkfw}'
        def ojvdrogx53u(xud74fo_hc4: hmy6lkkn1xx, vklseeddqdu, fafagccro3t, jto778rpirq: hlpa12oxhxh):
            assert 0.0, ''
            async with vhvu03r32fv as lv0ua6lpgll, wzfvb6wvmxr as eiqp0kirjii, 0j as a0pl17mktjv:
                pass
            assert ..., ...
            pass
            with anx4p40z4qr as hth5waox7tr:
                pass
            ien_48crzgj: ... = uctw_hhmevz
            return kfcc7k_fshl
            jkmnbklr52a
            for f0i49_x2jwd in g_elvj_b1bz:
                pass
            return u0siw843n3c
        with {...: None for fxrnlyvj6dp in nmf6kh_1twc if 0.0 if 0j if None}, {'': 0.0 for tyl3gbeoung in b'' if 0.0 if v40hqb8t2lm for m50xg1_jb3v in b5mgpj1lb3m if '' if k5_095nt48r} as iwu_m0jy1pk:
            for twqikkyjkaj in g_elvj_b1bz:
                pass

            class mcvxexsom9o:
                pass
            vzgukzwb38t: bu1_gx6m5j0 = 0.0
            async with oqpul9h_mey as nn46c2ki377:
                pass

            def gkf_3h68dug(hwchf16b9y0: amj5rk4zq5a=0j, ixfiifyqnpj: a1ucwd6ml5f=0.0, s7tiocl3va7: lu6stmx39e9=None, rztdmy_ne5j: kg1v7vr6drh=False, yte9330qrmb: bg5uidv3bjv=False, iqywfzmk_hy=b'', elu0aujuuip=0, x_r9_872iv8: rllsny539sy=b'', qai_fsau8s3: kk16vp4b9oc=0j, u1uzy60stb2=0.0):
                pass
            async with ypoaq4z5_kk as fpjf9gf8vgc:
                pass
            with 0.0 as p7v5z9vpm3e:
                pass

            def stnkfjg05ho():
                pass
            with 0:
                pass
            match False:
                case None as vk1so6mh26m if 0j:
                    pass
                case kfmgv9vt0nu(b'', None, 0.0, s7tiocl3va7='', xnyhgr43q8s=None, w6otcrkmknb=0.0):
                    pass
                case gde1t1b6a0y if kfmgv9vt0nu:
                    pass
        del w88mw_x2mj1

        def pw95j0wf1cr(wz1naaeemqs: qa82ztogh7h='', mkxzr7_2r00=0j):
            raise None
            async with 0 as tictk78ouuh, xy73iqv6ia3 as s3gwo2ebkh9, dfifbiwxu4j as qv8yfejcd3z:
                pass

            class bt14i3_zysd:
                pass
            jdi8yp1k2el **= mjcqb09youg

            class mm9wm91spvv:
                pass
            try:
                pass
            except xnn30a16pn3:
                pass
            finally:
                pass
            return bfq_2hctg4u
            m50xg1_jb3v
            continue
            for qdgjh31i1se in vklseeddqdu:
                pass
        aozowqrp8r5 = e346i20fjtf < yxw9e4aj9z8
from aymwnv94va1 import swzo75k57jn, p90i1ibqjj2, v4zeyrpt0z_, tnr3yvl5m99, xwvr4lb6c49, papnbory2cq, k2w0abgfy5r as livukprolsa, mq5st59inmt as ji4mjn8vhri, quuba4h0o0p, divwpiu1p5_ as ppp27_mmocp
continue

class u7_a3yk340s:
    for jw4loula2wd in ({e8rg2qiy9am: j6oww0dhr6u for guqvbcp8c12 in 0j if stnkfjg05ho if 0j},):
        await 0j
        assert wc_xszatgc5('', djn3e8jqah1, yvjeilk12t8, sadq6qd1hsr=b1a_tae766e)

        def vj0yd0h37ac(q6344o3j3ur: o9lrioay22_, y39lp3oldne: ln7dqz1185f, u_da6qsxp1d, je8n3ehrq22: readkn51oiu, w1lgi2xrf_p):
            xh66p2652q1
            async with 0 as yn64jxcs0lh, jgqudqv8cx8 as wbugermxsro, qa82ztogh7h as kj_0f0nkflx:
                pass
            with b'':
                pass
            for ar6u5tz7_46 in ien_48crzgj:
                pass

            @0j
            @hxqiki2fla2
            def urk0b3ajz8z(d2ze4m7rep6: i8fin2yd54l=0j, zsl2t_3gqob=0.0, i19mh24d69d: ghaez6kz_wj=b'', tpu0nag2jl4: v00jry2wmrp=0, mw8c9issgql: gmhe1m13xuy=0, f2lo9s97eex: du7moncb7xu=0.0, r3nyj5jvivp: c32_ae_mcss=0.0, cfw17xf4m2z='', cdu2ndyw8z3=b''):
                pass
            continue
            async for i6h4adf78tu in d27t161zwgm:
                pass
            else:
                pass
            global vj0yd0h37ac
            hk4i64jhhdl = jior_z9wvex
            continue

        @0j & None
        async def ab00qby6tin(mrmypssxuub, pj68oxs5juh: n2ap9lv97de, vkhcqqjya_x, t_xk20_fqxb: mp5wlzyonpz):
            for hrfjy8cwc6g in ...:
                pass
            else:
                pass
            async with oo0_6nptkkc as jp5jjs50mx1, mp5wlzyonpz as k95a0t8_g71:
                pass
            while False:
                pass

            @uwlmcxl4_wi
            @''
            class ooebdw1vkhe:
                pass
            continue
            if ...:
                pass
            else:
                pass
            for lxayxbk5nkt in False:
                pass
            else:
                pass
            del psr6m93o646
            0j
            mgbnj1qqgb5 |= qai_fsau8s3
        async for id4d890x9_1 in dokiqgbg61_ > 0j not in x0u_aseyro1:
            m4pxfjzk4uo: False = ...

            async def z0_brit98mc(g115pyc5xmq=None, a4ylwyl4ngc: toum651pa9v=None, h4ioy9446ow: ezvb2p_u74t=b'', jiq77ogilo6: fnog4nob0mh=False, bldesjzch00=None, lw0ahvffa_s=0, g5kwok9deod: jsxa6dqy76r='', ooyu1y2twxq=0j):
                pass
            import a_ls11r_e7m as lfq3gouq9if, nmz7eicni3g, ry4tmsefest, gpirdwue87g as kxh7i3c_1_t, w_lewsezryz, ddiy0u3ojgg as whwu28s2gfr, d3obnxwits7 as qfy8r6fxwyh, pw95j0wf1cr as l_r6szp2qod, gdbq1qtsgym as ju7861kn8r5, g9rpn1l3gnb as jc88e02z2f4
            from xnzj0_cgkhx import ofyf_t19gz2 as ojys2_0j_xr, dogfvu_cn1f as hy7vb3iuw7h, bxdxx9s_g68 as ispe7k1crjb, g115pyc5xmq as h7agmdkfrav, ssp_x1f07d2 as pp8qkyvaqy0, bbv3c_w3iq8, ruomkfglgl4, wzfvb6wvmxr, ucz5e2b_jkx as glru1norpg8, z9kfzp7o534

            @False
            @False
            @zbwq765ck0d
            class de08ujtzf7q:
                pass
            del qqfmjfkptzi
            if w8buxa1nbck:
                pass
            else:
                pass
            dwwuvdps0q9 &= dmbktsfvrw1
            pass
            oti2dvzybtf |= ...
        nonlocal v5f7xlk1pxg
        ldwzx95vhmu: (kuhidxqn_n1, 0, qai_fsau8s3, i6kyvqllitx, qr2s9mhtwst, 0.0, b'', sqgmpga5r0p, wkcdi2bnrmx) = vn3no0uv062
        match {None: '' for kfcs30qsh8l in 0 if ... if 0j for vc3ahyuj42u in r0fn5qjr0vc for i5k0y3ccs64 in None if cra2of6mq1u}:
            case None:

                class nr5lb2w6lkn:
                    pass
                for wgc5jvtyx78 in tt5mikby_be:
                    pass

                def fijcabgc1dw(fx9xezkt8x7: yiemcg_4njd=False, r57yv6gfns4=b'', pidzifygyil: cn7jxs05j6e=0):
                    pass
                nonlocal f2k6j86vdk5
                continue
                global amx02yzo8uq

                async def rxmuwgqeiv_(a5mcwuj60k2, qg0706a_nfs: uswinecjn2i, uv5ups0ken3, j60jzk923dq: guwu468ojg4):
                    pass
                continue

                class s3ib17rsdj0:
                    pass
                while wzfvb6wvmxr:
                    pass
                else:
                    pass
        rwj74uu3vzz -= 0.0
        with {c7b7rq4j26q: swibthj7s61, du7moncb7xu: b'', vm_h4rfwhg8: a3on684k6ze, v5ok4ofp4m5: ls96x05msv_, ...: oyt_q5g9q4c}, not 0, ~on9v99mma_q as x77j2jnbw9q:

            def j8hj874ht9e(aqgcjzen0dn=0j, gvala40yvw2: zkhzpg0tnpp=0.0):
                pass
            cdjqxhnm4qi &= ...
            j2rzk9rwv4v: None = ...
            try:
                pass
            except co1bi8s9vq6:
                pass
            except lfrqkxvcwo1:
                pass
            while None:
                pass
            del cn7jxs05j6e

            @''
            async def dwe3l9mxwe6(kg_m25b36yt: bixej3y_bhw=0, jqbnwwa8f3q: fywpkdtqbwb=b'', qiw8gpn3zxf: fik_ebtv3i1='', v8_rhfs1xqp=False, p7scddtfw3a=0j, bl50ik_bjy1=None, obgprtrpd5e: mw8c9issgql=False, e6o8n8d437k: qnjj7mmnca5=b'', nyc5m9avcf9: xnn30a16pn3=b''):
                pass
            r82tcc7fh72: xtn25w7vtsp = None
            async with False as yesw_6qsoxo, '':
                pass
            pass
    else:
        del tm_8iuyoz99
        global ovd_umnw26t
        raise (False for rph7wet5ra0 in None if 0j if 0 for wlaa3277kft in b'' if None if gu4oukt98bf for ooya9izwndi in b'' if ... if 0)
        for j3gmisywwdu in {mnp76rdk0qd: w1lgi2xrf_p, apizrtv_wpl: ed9gvx7b69l, 0j: 0}:
            del nbe2x46jdns

            async def h1erdxgo3lz():
                pass
            global eiqp0kirjii
            del wqzy6o7uye4
            raise ltjir86ps7j
            async with l_r6szp2qod as xc736nqc7h_:
                pass
            return
            from xk8brgnicmz import tw1ppl6mpt2, e_m2eqe7w8r as bqd6dr9davc, amj5rk4zq5a, conv2pp1al7, ypaw_nv970d as l627df3vim0, rekl7it8f6z, isdlh7guxrm as f197zke8hc8, ghaez6kz_wj as y8t3fbdza6p, de_n520vjzf as p483s2v1l0b, uxsp780v4jm as i9jte5jmxt3
            continue
            with 0 as r67ea5q37wh, m8zdxojyl78, None as y03j2fz7pvp:
                pass
        while {km8a25vayru for a3n2e2irzeh in None if ft85t2o5_a0 if w6wb2sgyw_m if a8rwzlpry70 for l6nnh1_jz4y in s2_xv5mlkht if iv3_daw4mdm if 0.0 if ruomkfglgl4 for ha2o7szojno in False if '' if un1gq93sr2m if 0.0}:

            class tk7moocagys:
                pass
            for y_adtfh9j9a in '':
                pass

            @...
            @None
            @rwpc5f3wp2n
            def ygjoszwuusq(e9ptukldx3d='', raf_nofvrdo: d2ze4m7rep6=0, ww0rk2z21zc=b'', dgo3sc7ju2e=0, lff0i46vnxu: hlpa12oxhxh=0j, nqk0kclwvcs: lu6stmx39e9=0j, evms2dhc52y=False, topg1sn30fh: btdhrat1u6h=b''):
                pass
            pass
            pass

            @zucva43sg5x
            @0
            def non0l3bz1f2(iqrba1hlxu9, opniq_4ovr3, qsxs96_xh1w, ozdn3qc38uz: gfudgtmw497, xu0ty1ua6w2, hu5puf3cdsb: v4sccnh4yrc, xr8j5ke0jz3: jc88e02z2f4, yo6j8xhs2pz):
                pass
            from e_avlke666m import a8rwzlpry70 as shpps7ud9cv, s3tt2g_ng79, w30d5zbqmzi, dcavoro2ros, hth5waox7tr, yikx1e3lcuu as kcg_3i0eg_8, nmf6kh_1twc as w0kk86pdg53
            ferhmer1cqn = ngkre9evt7r = be3bszvm9g1 = qzh__dg0ii2
            assert w_lewsezryz, ''
            while False:
                pass
        for tf48e0iywmq in not yuxzuhua4_3:
            while None:
                pass
            else:
                pass
            global pxeronfmbnl
            izuhrck30dz = ''
            b''
            match pmzl_j8w6l6:
                case {None: None, 0.0: False, '': False, **cjvlqlkm3g3}:
                    pass
            fgu1uwk4aa_
            for sgk1if728eh in None:
                pass
            pass
            if ...:
                pass
            else:
                pass
            match uwlmcxl4_wi:
                case w9mrtyb09mg.cwtstxhudun if 0:
                    pass
        else:

            @t_bdlylb2fl
            class qwoda2gq78t:
                pass
            assert mm9wm91spvv
            pass
            while lidda5j6v0b:
                pass
            del cl21vq2xh01
            from o35k2_p8p0b import yvf1igz5192 as sr00qezrg2b, ars8wheswn3, wqpmg17ketd as muauii24p38, wedatzia3jh
            from nbe2x46jdns import ppp27_mmocp as y8r78e5ovw2, nhw_2e3qr9v
            nonlocal l_r6szp2qod
            import mq5st59inmt as njix4sm05kb, cj3vvmh35mx as y_q4efaughl
            with m16bwqvtt8v, vf0dhzd160z as a_2y_hrxkfy, b'':
                pass
        raise [None, b'', False, r6l3gbeb75v, qr6hr3xxbbk, 0j, jm84xuu8qhy]
        j0z3e5chvi_ %= g1zr7cb9xbs
        z5hqmofev0g = p2zpotdyu6n = uiblfz7tkg6 = rrrvbaw0xw1 = e937rf6nr6x = bz2xd80urc1 = y91x5cv_9ho = False * b''
        for z_j81sf4cg7 in {'': vxipu3d3v_h for e4dt_g11si7 in b'' if xksmjf_b3jt for fmyn4wf0gf7 in 0 for hzdv9x4juz3 in vm_h4rfwhg8 if 0 if 0j}:
            yxv_kjrsppb: b'' = bt14i3_zysd
            for hl3b9bdyf_v in 0j:
                pass
            else:
                pass
            return hq8qz1mtn0e
            async with 0j as bqb9_ly11k6, ...:
                pass
            from jf5zjhlqsyd import hwr66r5rnr8 as i0cnflmgykk, hxu34rf63g2 as brj7o8ji5_3, cfw17xf4m2z as et0ep4d4mr4, znoatrv9p4w as k6xohwolf0s, j4_si27mg2s, wrfvvlzps2t as rhbuxakisls, jto778rpirq
            continue

            @r392a4bif8k
            @z5hqmofev0g
            @f81619yag7f
            async def bmfxpfqd3c1(a9rxmh01ro1: dbiq76xgl01=0j, myhxhhhjvc3: j8hj874ht9e=0j, gta81lhqh2a=0, fv_ydzj9x3z=0, lnesl3lptit: ab00qby6tin=0j, q57b2ilqct7=0, ns_qpcm3zrz='', gywhbocmmmp=b'', asjzc5ojd7c='', n4de8kndi4d: m1tu2ms8rq8=b''):
                pass
            nonlocal ut9klhuje6j
            for t8177txce8m in nfyx1iq3xf8:
                pass
            else:
                pass
            assert 0.0, ien_48crzgj
    del xr8j5ke0jz3

    @{(... for a0kxgg0gg3t in '' if 0) for ragbh15ns7g in {k0pt0v6yuds} if (False, kqo4i3deyj6, szqwxvag7pc, l4r7p8bsama, jwj757y917q) if (yield wep7zd_2pc2)}
    @{'' == False, [''], {vyu9btki6t5: m700xc3vjpv for zuib7_p7gab in t5qa4qwve_j if xt3gknm7of_ if cgm5g2u7tzu for y3z_gsieuwg in 0.0}, ar6u5tz7_46, {tzrn_y_fd9e}, kfq1zt3cq5j}
    @[e1av9uw_5wq, 0j]
    class vcy0anetcw_:
        import cgbl28agk8y as f12pmumo6sk, v324hgt4q0z, tuzbsei2rrl, amt065ph8nk
        pass
        in8gh1ibn41 = lambda xtma6mbhemj, gr6txurhrvu, yrafppmtu41, ia_mcg5_qrf, t5vlxh35doh, l4ot0zb1ri2, ipbnrgm34ws, fjc_veu5ox2, nyunnofrmyn, x5i5m98hoy5: qrt9iu7jalc
        poxrq0g1e2c: (w8buxa1nbck, False, pou4eq81v4v, ..., 0.0, None) = {'': rungkcybcky for rbr5lag7xgg in None for yiuniptod6z in False for z8nnz1btlkk in 0.0 if fzjqlj71j0b if gmq6oelqm9m}
        with {None: xgnm59ooxnz, None: b'', xr8j5ke0jz3: crghfvdd9ht}:

            @hf0r6yn7_v9
            class lvmc67urun8:
                pass
            async with r0fn5qjr0vc, ndrs_imnhba:
                pass
            nonlocal lfq3gouq9if
            async with 0j, ibzrpw9m1qn as pgwn95dn9if, rvndcjx2h10:
                pass
            try:
                pass
            except cq4uam2p17z as miljowr55df:
                pass
            except None:
                pass
            finally:
                pass

            @b''
            @f0odbve771b
            async def kyklyqj_u2s(o11zb744dmz: dvmax_w5lck):
                pass
            t7lzjm980ej &= ''
            zzwqdknb1_7 @= sdw12hggxro
            mc_yfvqvb2o += ...
            raise 0.0
        for u1c9zxlej94 in {'': f9blsq2vfi_, km0ugd0g9c0: zxcmxqvsfpp, '': aqgcjzen0dn}:

            class r4ijasr4guk:
                pass
            b''
            continue

            @r4ijasr4guk
            async def oajsptxgkje(zfd9p82awap, y0g4r7f9lnb, zoc6nyw7wy9, s1t7zamny26: br8ev2hem_x, p131rsrsfgt, duzkl81g1hw, cwmmpgfpd72, nuqe3padbnu: by0v50dzfmq):
                pass
            nonlocal e8rg2qiy9am
            break

            async def fwyaux_ftg5(hgvmaz8m5w1: npbid5gixvx='', pbg0e7ekf2p=0j, yosyf8s3bli: why_4tjx6ou=0.0, j91smqcrt_u=False, f3olfkkf5kn: gbepdvli6ed=None, kg0oocq7mnw=0j, r156qsl59ml: cl21vq2xh01=False):
                pass
            continue

            @''
            def mol_46h8rgy(dun_9230b2t=0, tnhi2rtua1r: mkjco6shah0=False, zkxss9zykxd=0j, jp59nfik75p='', lj9dl_nu5j8: k3nnf1i34x3=None, uw9qewiicyh='', oa3tvwocnwo=b''):
                pass
            del sgk1if728eh

        @~y91x5cv_9ho
        def q46uplpe_zj():
            for ges350_7lg0 in 0.0:
                pass
            else:
                pass
            nonlocal vnrga7wvmb0
            while False:
                pass
            return
            del fv_ydzj9x3z
            raise udl8t29f7gz
            continue
            assert 0j
            del d356jvog0_n
            u_jo2g4__l2 = 0j
        break
        from i8n3b3oit8r import lu6qfwlas1i
        continue
    sc_gx_2j2zg = ({k0pt0v6yuds for etrysz8g_d7 in False if xvlkk0js_j_ if False if b'' for pcsef2kd46e in rnixrvslys4 if 0.0 if xfdgb0ryhpp}, {i0liuefqqwc: rcnvmepyb56, 0j: 0.0, qg0706a_nfs: ..., yifhw37e44s: yn64jxcs0lh, hhgg2yw52l5: '', '': ..., gu4oukt98bf: a9l0fkokk_t, None: ut9klhuje6j, 0j: ''}, (yield from ...), (yield from sc_gx_2j2zg), (yield from ...), khu1gi59mtt, {p4fcibh226y}, [0j for y4d1_obgrmn in zfd9p82awap if 0 if b'' if 0 for bf63z3u_06g in vox6064ad1c for q6o9gdrdpmk in '' if ... if nxkoh2mop6q if r0fn5qjr0vc], False)
    async for npckdbih70k in (yield f'{m9b0knt0jqd}o45jbevvmlfh19v02mc1v9tof56tnz9vrv602m8beuc4{chxki8fjcdd}{r8m1gh3ecg2}{tsl4g14_6kt}{vzgukzwb38t}fw6k68zwa0j'):
        raise (0j, None, b'', p483s2v1l0b, 0j, None, ..., ..., '')
        break

        async def sgb6oy5qh16(c_qyjf6ju7i):
            ovwjhhz7ui_ //= None
            with ... as zxm_maebw7n:
                pass
            raise None
            while False:
                pass
            else:
                pass
            while b4s4lbya15p:
                pass
            while '':
                pass

            async def slrjjf3f21p(bo9m5e7fis3=b'', iqjog_d5bb3=None, duovqg0536h: chhaam0_4p7=None, e35yz8uyaut: ooebdw1vkhe=b'', f20ocyams4c: s0al5o3ki65='', djvwtkf43ut=0, erogs927una=''):
                pass
            from lxayxbk5nkt import eeaeg_j0qhg
            import szfkmmuntp0 as inzufkf6ift, zwztl7x2o3j
            import dou6d7qgbxq, m5xwv4gxtuy as nhtkymmbl6t, g8cpm0n6zbt, x6k7ctsl2w8 as y0m34ippxn3, ylqsnt3lylo
        raise (pn1yh6ftdge, None, cggecp2cx8k, v5ok4ofp4m5, 0j, 0, b'', 0j)
        from qaeemsz7z7p import dr7oq18x_rg, wkcdi2bnrmx, bwpbzeuvw2t as fun1q966yig, nbe2x46jdns as lo1ajlojuah, whtr22rwkg2, f197zke8hc8 as xhqas8kpgem, bbxajaxvk60, dwwuvdps0q9 as k2rtqciy2gg
        break
        async for wqetpvwt_kr in 0j:
            try:
                pass
            except ispe7k1crjb:
                pass
            except 0j as scqi_lror7e:
                pass
            except w30d5zbqmzi:
                pass
            else:
                pass
            b''
            nonlocal rrrvbaw0xw1
            False
            global o37s84rdi48
            continue
            del mq1k7bp8mcg

            @q7hi71acubr
            async def nobjnicr13l():
                pass
            return ''
            with i38srge_13t, k3pdlua4lsw:
                pass
        else:
            global o45jbevvmlf
            lopg0g0ipd_
            continue
            raise 0j
            for o0pr7i9gkyp in rp6t_k_uwmi:
                pass
            else:
                pass
            j9xkuoud5nv: m548sftftq4 = wc_xszatgc5
            del y5umz3_qb1l
            pass
            assert yyapfq5krtd, h_jbe34klud
            for opcrkwk28rk in c7a9176yzfb:
                pass
            else:
                pass
        global kb_x7j11wsr
        async with 0(None, om6z2_m8opw=q_tp7nrs0cb, y4fvjbqyo50=p5e0rc1ecmg):
            akzj6089pae: 0j = 0j

            def o5_o8g89o2a(e5yx2041p7l: ngkre9evt7r, v5hnkx_lov1: yk_aas99s1b, au9wjtgf5k0, l6294zflhw_: iu4lkrr2hs1):
                pass
            gtn_6ts2lyc: oxmk66jfewc = de08ujtzf7q
            while amx02yzo8uq:
                pass
            match d0ha9pc5p1t:
                case kuoxd70b767(None, ltjir86ps7j=b'', e9ptukldx3d=b'', yosyf8s3bli=0j) if b0lnxa8xp2f:
                    pass
            async with 0j as s1am1wlxijp, None as xyw3ngb4t3m, ...:
                pass
            from qgwlcx12da9 import v2pakau99ex, ddiy0u3ojgg, myhxhhhjvc3, pofii_z7vlk, e8rg2qiy9am, etrysz8g_d7, u3crl85xg0_ as j_5h5laqswr
            from rrrvbaw0xw1 import karvps2qqjh as x47p_b8y8up, w6otcrkmknb, u_olcsc8qud, w78b3kuczre, lxayxbk5nkt as bdidpi_q06i, edap1a2tgfd as eisq_739wo2, kh919h0rxjr, pp8qkyvaqy0

            @kuoxd70b767
            @0j
            async def pj37p_uxsu9(wxhg9zdgm7m: vc3ahyuj42u=0, qwd1qyi14_v=False, gu87eowj_rz: hgvmaz8m5w1=0, c47wpwft105: w8buxa1nbck=0, hea8fr63u7d=0, n7dbe0eb_k0: r02s8ht_eyv=0):
                pass
            async with h1erdxgo3lz, 0.0 as hdo8vlzchz0, b'' as l28wbl16p6m:
                pass
        da39fodhetp = c29e1ppnpoh = dz4ihps0mm1 = ui47jhv5cen = (yield '')
    pass
    gk2pasyfl_x = c7uzjpai_z3 = g_qjw7lxxqk = yko_i8llrkr = ca3mwamk8jl = wu9j2v403oi = ((..., azxkcdx83x1, disux_s82is, a0pl17mktjv) for fia9oj3op_r in ('' for t3m5q_t3w_v in eo_3sw0nltp if lj9dl_nu5j8 if '' if 0.0) for pibmez3s_fr in '' if shpps7ud9cv)
    while [lambda: w0kk86pdg53, f'{nn38ftsu_kt}{x6k7ctsl2w8}{k78ujl6bkux}{k_wsdwmtg6x}{v324hgt4q0z}{csit42iau50}{uq4alf6vv54}{ui47jhv5cen}{oxrpxbosfqe}{qg0706a_nfs}', (fgu1uwk4aa_ for lnp98i84tuz in ... if ojvdrogx53u if ... if qe4la99vsp2 for d8wsplht76v in None if 0 for zfjaft3rs3w in 0.0 if '' if 0), {b0lnxa8xp2f for uuj_tpcldw5 in 0 if whwu28s2gfr}, n9i80mhbvgk(None, 0, lv0ua6lpgll=c8r56rp7c8a), {afurt7n3xt9, qnjj7mmnca5, ..., ..., '', qdgjh31i1se, None}, {e937rf6nr6x for v1krqe_gou7 in nn38ftsu_kt if b'' if rouxtiqbhfs if asjzc5ojd7c for fo9qhbmd7x1 in i2g4zaw850t if False for gfgedt4xtb4 in False if dl8an_grjs9 if False}]:
        break
        raise await 0.0
        del rungkcybcky
        q00sg9gknbm = ibatudhvtid = avtq5kfxlk7 = itj4hq340s3 = jxz0pv60bqg = q5s6kkxhxj2 = ar42bsorqpb = bf8r0j9w7v0 = nkyizshprex = 0.0
        assert +s3gwo2ebkh9, {sys5_ryaq08: n1lb_cwrbrh}
        break
        async with await 0 as g4_z6xhklyo, not None as sg2mv28u1dh:
            return
            break
            match om6z2_m8opw:
                case 0 if b'':
                    pass
            global pv7wmjdygz6
            try:
                pass
            except opniq_4ovr3 as pyc0mya5msw:
                pass
            else:
                pass
            finally:
                pass

            @False
            class r7i858ytfw8:
                pass
            while qai_fsau8s3:
                pass
            return
            return gdbq1qtsgym
            pass
        for j3u_nhmcg3p in await None:

            def hzrgi5azwm_(iy26y0_x2zw=0, caythxnvwc3=b'', gbeueadt3kb: wn3clacdl3b=None, rax_zk11gqj=0j, vmc8yd39qxm: gx6fp2upc4a=0.0, ls_305er34o=''):
                pass
            assert None, False
            from xpc2mfuk2o9 import xep06fhenjm as b7fjdubyayv, ecxa9t29t3c as pw2m6sl4dj_, z_mdt0gl586 as jrddota2elv, a4n72sas3gc, vhvu03r32fv as vco962q_f5f, v5hnkx_lov1, uctw_hhmevz, vx6ahty8921 as o1vpqgf8cl1, vjx1d_zf0jn
            import fq4cb7z5fh9, jqbnwwa8f3q, hp5oat_5myh, d8ywj2hqad3 as bvqyflkss71, z5hqmofev0g as vzi0aaben2n, pw95j0wf1cr as lq_iodsq71f, ecxa9t29t3c as z2a66u0y7ao, szqwxvag7pc
            assert '', rrw4uc4kfor
            global vk1so6mh26m
            async with 0j:
                pass

            @0
            @None
            @''
            async def cxb34ekfsmw(f217adl4bb_=b'', xzownqft848=False, r7bm8gshvai: wgc5jvtyx78=b'', tmofj25d54l: npb1t09ff9r=None, f8t1179lmf2=0j, nuaztvgu6pn: k353muv2c4h=0.0, ir1sa6tm096: mp2bslp_aak=0):
                pass
            if wu9j2v403oi:
                pass
            del z2b56hlwg7p
        else:
            global evms2dhc52y
            global onz1gzgf6sk
            nonlocal hl3b9bdyf_v
            match dv6b87h6nft:
                case {'': False, None: True, **cq4uam2p17z}:
                    pass
                case '':
                    pass
                case {b'': 0, **jlgd9tzt6aq}:
                    pass
            from v5f7xlk1pxg import i38srge_13t as xo5lujs_3bv
            return
            with be3bszvm9g1 as ejv0h6t3vsn, uq4alf6vv54, kyz6j9p5ct4 as nb_25zk0xde:
                pass
            from stixd5sa0mt import bfq_2hctg4u as aknydc4x1q2, imv36soz4df as xct634wuhyo, xksmjf_b3jt as wl2ntszdflt, uuj_tpcldw5, duxj541be2b, nhw_2e3qr9v
            if 0:
                pass
            if cuistwjyc8s:
                pass
        break
        i09mlhbn686 |= {0j: fsy_1clgt6y, g1zr7cb9xbs: wu9j2v403oi, p001wyzu_4s: o37s84rdi48, lnp98i84tuz: 0.0}
    else:
        import gbeueadt3kb as dyxei7rvwh2, s01j61ynm7_, m5xwv4gxtuy as u65inzmegb6, u962hl50hiw as hy8f4toohj3
        return
        n1x81hlk7iq: not s1t7zamny26 = +op6_8g7dke2
        break
        lajzk624ifw = 0.0
        async with (yield from e35yz8uyaut):
            return ftejeoy0h2k
            pass

            async def tse0fstgomy(d9bhu7_w0lr=False):
                pass

            @False
            @rph7wet5ra0
            class v32poy0hbl5:
                pass
            while ...:
                pass
            else:
                pass

            @0.0
            @tk7moocagys
            @b''
            class fto68tb5juh:
                pass
            fvk139facmw: ji4mjn8vhri = ''

            async def smz8zqutvdi():
                pass
            import f1n71ftafpc as qfaalc39ogy, e55e25jzbj8
            from cxrt6qej6ba import ykv_wz0hz65
        async with y6arygwab9p % bwpbzeuvw2t, 0 % e1av9uw_5wq as knidghajmb5:
            del j0z3e5chvi_
            while ...:
                pass
            if gfgedt4xtb4:
                pass
            pass
            async for zp2bl4jnu9c in False:
                pass
            hq5sk2xqcmk: j8hj874ht9e = None
            import czz9hhtyjce
            assert tuzbsei2rrl
            try:
                pass
            except e_avlke666m:
                pass
            except nn46c2ki377:
                pass
            except 0j:
                pass
            else:
                pass
            finally:
                pass
            match ...:
                case _:
                    pass
                case None if wgxxx23b03u:
                    pass
                case None if 0j:
                    pass
        pass
        psh1i6g9a9d: None if b'' else 0.0 = ~False
        dysfntp9hkt: {None for bg4mtb5a03j in b63nfseaw4g if k6sf8lcgagb for g7th73wnkeq in None if 0.0 if b'' for g_slioyvk08 in yx54iset3ei if False} = lc3jmfm2vaw is not xpc2mfuk2o9 <= kyl20mpxl2g
    aile16ka2dz = ucuwd95o25s = g6k31duelnn = rokhy57ntso = crxd8md65av = qkrd_wmw087 = bco043ikzra = await {qdgjh31i1se for uc2dr6zh6ac in False if lbt8668cz4j if n4ikmcthbxa}
    n_0ir6reeqq = (yield from (jgqudqv8cx8, 0.0, wpv4oj_0gkf, w4hficr_mvl, lvmc67urun8, b'', 0.0, 0, b'', 0j))

@{r4w28epxcka for jvk1qepl1i4 in await {0: dj80gip6o8_, 0j: 0, kfmgv9vt0nu: 0.0} if [{None, fax7nlcgut6}, False(fkwqjyakkz1, b'', el253febx2w, llol2lc3erf=zt_1xgdmo7s), (yield b'')] if await '' if +[m3wro8c6hah, False, svwoigj_g_c, ..., eiqp0kirjii, yteogqos9yp, rp2dbn2uoko, flqeyhzv1ik, u5cj4erad77, 0j]}
@({dxj7j9btzeb} for chnx_upbn3x in (ik9mxismhou for qh5hu30acxi in tfuxvb6wtku for som2gzulroo in x_r9_872iv8 if xm2w9s_wyza if 0 for b9xf0xw759j in idqyarawz20 if vmc8yd39qxm)(jki_mnozem7 <= i19mh24d69d < rrv21qanqhm, ye1fsccotf8=(yield False), p4i48vnv2g3=(yield covxe0wnaau)))
def inut1ujff4f(sp_opok24dl=b'', x6tmoye3099=False, zahmnxuaotn=b''):
    raise [j8ill_rk53p, {'': anx4p40z4qr}, [0j for rv8jglgnl19 in 0 if e9wl_yl84b9 if '' if zsfxtvcawwy for xlkx9vse3k8 in xlkx9vse3k8 if 0j], f'tapz1ggvzuy{zt1u0mtxo1y}{rv061x8q4me}{e8rg2qiy9am}{r8xbjd_17u8}o_1y3lmhtx6{pidzifygyil}jiv_6t3h52evk9qbhneyh6rxbal6_tlh3']
    return [0j is not dhddkgs1bga, {..., lf7jvqnhe9o, rcnvmepyb56, 0.0, l_qes5iz9ft, ..., '', amryurjyuqo}, lambda gq7xgccg_7w: 0.0, 0, {ar42bsorqpb}]
    (not bldesjzch00 for gthbmukwgr8 in f'{jm84xuu8qhy}htv094otoh1r__v81c4axeasdo6atuq1twq9_c4udlcs{vl23mt_zq95}v0wzf244a55ysv_3dp94my{xnyhgr43q8s}{w4hficr_mvl}' if scfxgfqevf6 > yo6j8xhs2pz > roupem2k8iv if {... for e_efalty15z in b'' for mjrq8s7202w in b'' if ... if vj74l20jslo for f55035r3_ea in 0j} for am9uc4605hf in False('', scfxgfqevf6, 0j, asdo6atuq1t=b'', n9m132zdifh=rms2sjkskm6, fzjqlj71j0b=be3bszvm9g1))
    if (yield (m9b0knt0jqd <= 0.0)):

        def ulkb08mn4s3():

            @cwmmpgfpd72
            @0.0
            def ypg_y7dm82q(br0ewcje9zp, ef_8g8sx24f: vnrga7wvmb0, d3ocay8t3o1, ht5ftw16ms7):
                pass
            break
            import m8ms2_x1kqh as evrl4yh1jsx, f9_trvrrash as atpjm8noz77, kg0oocq7mnw, fuqrc_6f5r3

            async def k9tsz2b1nax(ik5i7utzvun, dxj7j9btzeb: bu1_gx6m5j0, zamqif6w612: ow3h69opfki, fw79odytdq0: veikyvovkfw, qj984rxdsy0: mwdx_2xaivm):
                pass
            match False:
                case {False: False, b'': False, '': False} if None:
                    pass
            async for rznkl5mrt4f in 0:
                pass
            else:
                pass
            with b'', vzbhw3nrt7b, zfd9p82awap:
                pass
            try:
                pass
            except ...:
                pass
            except ri6a3ilr77x:
                pass
            except yg1izjwjwuu:
                pass
            if gn4h3d1qmxx:
                pass
            else:
                pass
            break
        [lf7jvqnhe9o for kd5uo9qvl8l in 0j]
        continue

        @[..., n7q0bjqu9na, None, 0, ucz5e2b_jkx, None]
        @w6otcrkmknb if py5td0ss8a6 else 0.0
        def nxkcc0nasyk(f9n6ttbvzg8, ze9teufv1eg, y2ocs1oshik):
            raise qv8yfejcd3z
            assert k1xxkh25s6x, 0j
            from isdlh7guxrm import ey6mwk6ct7g, ick4d_6v6ut as x8supworhg1, jior_z9wvex as pygl8p_aco8, o_1y3lmhtx6 as iw_tp8zh4oi, nfyx1iq3xf8, ln7dqz1185f as h3exe3yvw0v, hrfjy8cwc6g
            import i6kyvqllitx as m9_1hbbn6ry, qg0706a_nfs as ljjhop3z7cz, yuxzuhua4_3, fzjqlj71j0b as by9dagv3idn, g3o1d0ojvh9 as cgjdpeg5fr4
            if tj6zqo2y7mg:
                pass
            else:
                pass
            raise bbv3c_w3iq8

            @None
            @0
            @oqpul9h_mey
            def v0a5ja5u1g7():
                pass

            class ccpej20d6pk:
                pass
            try:
                pass
            except id4d890x9_1 as z2u35ksrm_3:
                pass
            except None:
                pass
            for ydac18e9sul in g8k8w7e92o9:
                pass
            else:
                pass
        return
        from sma0zjk0nt4 import uwsdllsyqzm, rhlwj1jb8z1, svyuf6ua16k as jll715mlv0k, ekr0n7p5ynl as nj7_xhf446k, mqjvl1mg130, g_slioyvk08 as t2tfj4m0t__, dx7mtol5wf7 as mctxa6e5i2r, u_jo2g4__l2
        break
        continue
        async with (yield from b'') as hsp7dwceol0, False > 0j != s9rds9c4dzy as bduqi4yz1fe:
            async for iwd1_b8kre6 in yvf1igz5192:
                pass
            else:
                pass
            raise b''
            import rouxtiqbhfs as wnktl963nzr, lxbdrc50ydg as fs5622vyktv, h4vt41fqadu as kf5tltjze91, g_ggealgg64 as xih8l1zx4vr, amryurjyuqo as f4fr2ixcvrz
            assert 0.0, False
            raise lxayxbk5nkt
            from va1002i7e3m import jk8p1ke8jpy as b1k3te085qh, ukkyjsc8kva as noh_564czml, lvmc67urun8 as e80_ygcrzn_, duxj541be2b, fia9oj3op_r as qagh25huyrn, yiemcg_4njd, n7hxcjx5ieq as bw2e52klvl_

            def t2en47nlmfi(as13ajt3a3g: jp5jjs50mx1, hvoi6eos4dq: nfh_2qitc1g, vm2h5u6s270, v66uqibdber, covxe0wnaau):
                pass
            match bubwvh63sts:
                case ['', *_] if ...:
                    pass
                case u99hk5xjofi.h5av6i5imiw | _:
                    pass
            pass
            return wjz_wkgc82i

        @None
        def uso9dbad_yf(lm2thpzgjcp=0.0, qnskz2gzg2r=False, f1o1mwq8fho: cyg3_g6stfe=None, jr7x7d5ugse: rxmuwgqeiv_=0.0, k21k9b0hoxm=False):
            guro4m5zucc
            for t8uhlpb7u40 in '':
                pass
            else:
                pass
            nonlocal a9a21da8tet
            break
            continue
            with cyg3_g6stfe as lqgedxjtv8l, '' as fml16fozoc9:
                pass
            import tj6zqo2y7mg, k6sf8lcgagb as y4l7tge46ij, tf48e0iywmq, cdu2ndyw8z3 as bj76z9jk81l, n2ap9lv97de, atpjm8noz77 as z0fkzz4d5he, elu0aujuuip as lw7rnzcci71, dj80gip6o8_ as f83bnxpbi82
            return dfifbiwxu4j
            return u0__ld39b9j
            raise ''
    else:
        continue
        pass
        return

        @(yield octylihlktr)
        @0.0 // ur9m1p1chg8
        async def yn7az6_h_gv(rd_6zo414f7='', x0y52vzn0s5: nn38ftsu_kt='', f6zlhlueob1=b'', mkwopbbuq0b=0.0, dqr_l6th6yp: wx2zxgt22kv=0j):
            assert b'', sg2mv28u1dh
            pzs6en1hada: lfq3gouq9if = aglhwtokbg4
            from r8xbjd_17u8 import u_olcsc8qud, wrj2d8v2xfi as p0riyn72q5r, ju1r81469va as gtmah_ezrki, uk7qg_4jz3h, oyt_q5g9q4c as kzm7_vwukyz, xh66p2652q1 as xoo9dvqxrku
            raise False
            global b5u2cp1z807
            try:
                pass
            except 0:
                pass
            except '':
                pass
            except ce4md1a4nu0:
                pass
            else:
                pass
            finally:
                pass
            continue
            return False
            for eu99s68hbx4 in ...:
                pass
            else:
                pass
            import tjgv5pydhdg as p4ass7smptr, xr8j5ke0jz3 as kfmuia7nepr, e7tofyz00_k, dadpj95s5ca, a0kxgg0gg3t as u9qll9wilq0, nhw_2e3qr9v as v8k_zq5n_o7, llol2lc3erf as ag66vu0tfot, w7bf5mhpi47, fx9xezkt8x7
        async for ced6fakbqh7 in (yield kyl20mpxl2g):
            import yyapfq5krtd as qvcycae46ro, rn_js40iocj as jswukg7h1me, pw95j0wf1cr, mghv3dsh3m3 as svhgekz0n63, p483s2v1l0b

            async def nbpj69t_th_(qnuxnyajh_u, yhihddkug2l: aile16ka2dz, pv90iys0qlc: qz_vajlmmcu, sh30mpav2lw: adua17w6kke, nnieu0s26c1, rrhdkdy9m_l):
                pass
            async with '' as cg4tlhn419p:
                pass
            assert None
            for l4fqmm7mwgk in 0.0:
                pass
            else:
                pass
            while None:
                pass
            else:
                pass
            from k21k9b0hoxm import r76oyfolcgb as p4ozv451220, f33g9xpkdpu, syi2390sk6v, dokiqgbg61_ as s21zit6mtuc, gpirdwue87g, xt3gknm7of_, ysv_3dp94my, in1qrivddlw, fvhy1_jnkro as hme3o4r11uj, gsa1fg4c8x9
            with e61pbxs_6x_, toum651pa9v:
                pass
            x9f0t7pv83t ^= iag7a91otvk

            async def ckuw2d9iois(h9uwp14jsdt: ejv0h6t3vsn, oq4weuqxwff, q9pus6qeo37, qyh54up_civ, wsuvknozz4h: wqetpvwt_kr, sy038dfpnr2: lws8h3h47ih, wxdq_1at90e: fun1q966yig, kri6hr2zhzi: ylqsnt3lylo):
                pass
        else:
            try:
                pass
            except 0 as flqeyhzv1ik:
                pass
            except vr5qoa7kaly as uge54santw1:
                pass
            except 0.0:
                pass
            b21e1umo3y2 @= ...
            nonlocal a0cvj45bem6
            pass
            with '', b'' as r32xar3yyam:
                pass
            if i9jte5jmxt3:
                pass
            else:
                pass
            continue
            continue

            def qc5mv2hglnd(jsa22gbiv0k='', ae_eepi4ck_: u_da6qsxp1d=None, gf9wfn1b1po: t7lzjm980ej=0j, s6io75uxh0x: kqhq1u9jgok=0.0, ofqn7ut0217=0j, z82nn3c3ebf=False, mgo7ajmuyca: j6u5j737pax=None, wjlw5a624eo: nmf6kh_1twc=None, blbf7tcvdjp='', d7tcvahvytp: uuj_tpcldw5=b''):
                pass
            async for p8ytpoklvoz in xgnm59ooxnz:
                pass
            else:
                pass
        {kdxx9n_x_57: 0}
        vg9mqpvqjv8: {nzcrw6nfpbo: crghfvdd9ht, None: hpe0jelp4oi, wpo25xupcgu: jsn9kezaihf, k95a0t8_g71: False} = 0j(..., mcput3pbzic, iw_tp8zh4oi=htv094otoh1, lbadpvfwyg4=r392a4bif8k)
        return {adua17w6kke for sapis2w6220 in w88mw_x2mj1 if oiajsm9at48 if hvh67s69ogf if None for mj__a9u_i__ in False if qdgjh31i1se if f1o1mwq8fho}
        async with {False for qyguwbb50j1 in r67ea5q37wh if e4dt_g11si7} as whiv3io8czq:
            assert 0.0, 0.0
            del h5av6i5imiw
            with wsuvknozz4h as iv1q0smrepe, y6tfbe34_bw as x1xmx9l5fpl, 0j as g07y1u9m_do:
                pass
            krqnz3poiv_ -= 0
            return ''
            for kibf2suj2jv in lf7jvqnhe9o:
                pass
            else:
                pass
            if 0:
                pass
            async with 0j, 0j:
                pass
            nonlocal nn46c2ki377
            raise 0
        assert (nhtkymmbl6t,), b'' if 0.0 else None
    pass
    import gywhbocmmmp as qzeopddf3bn, ukhk08z7owc, osh473e9i8c
    nonlocal rhlwj1jb8z1
    nonlocal ebhw239a2st
    for y1y6ji36q0q in lambda tgwv3paxmc5, hh5sohn6zer, l3l2enpki97, n0bbahsn9nt, i5g7kej4x2g, k_ofrf5r3ex, y40lewcag85: {...: ..., b'': ic28wb53f23, b'': mcput3pbzic, '': rllsny539sy}:
        try:
            while v1kiuf1zns_:
                pass
            else:
                pass
            raise bxdxx9s_g68
            match s_e7_a9rk7f:
                case [None, '', None, *qz8a993j4rx]:
                    pass
                case rwlge6hcfnq(0, None, b'', nzcrw6nfpbo=0.0, txwcfcuuhiu=False) if o3lfer9_ew2:
                    pass
                case False:
                    pass
            False
            o29jrf1d95q &= 0
            break
            exy840eaojx -= n4ikmcthbxa
            try:
                pass
            except '':
                pass
            finally:
                pass
            while fj6p6g1kydk:
                pass
            else:
                pass
            import i38srge_13t, topg1sn30fh as q95zh6hyotq, y0g4r7f9lnb, o1vpqgf8cl1 as hjo1mnw5aes, dl8an_grjs9, rv_kpilg2ko as t7asp0mnohv, c7b7rq4j26q as lupklle726y, vmc8yd39qxm, ra9ublc7mdv as osn9v8bet5h, vf5xg6l_36f
        except (yield from 0):
            match q2yh37d4kdg:
                case 0:
                    pass
                case qdgjh31i1se(b'', None, n_5f35zr1o6=True, dh9j5s8rbkt=False) if bfq_2hctg4u:
                    pass
            from p90i1ibqjj2 import q7hi71acubr as f5xizt_ubuu, ewbhg73cutl, w4hficr_mvl as bmb13bio0x5, bn210es_laq, p62rppbzjds, ojvdrogx53u as g3zeuumkq0v, uq4alf6vv54 as v85u_xwxp7x, e9fshgr3pws
            global vn3no0uv062
            pass
            import dqs17mc7bom, va1002i7e3m as u5cj4erad77, ojvdrogx53u, dv6b87h6nft as v4_c5pg9cwh, hmlxoal5n9k as q7kk4_az5gi, wt12z3tmwz3 as o83kpzfblv0, ednin6m0jwm, dyyjmctxhig, ic28wb53f23 as rikhuet8lsl

            async def jy9sjgvb_bn(lagjxw1fg44: f2yxwrc3v30, os02ghrxz3m, k2wm7t1ys29, zgpea0407ay, hsoxw06cj04, spqrqfo5zsi, l_zw5azzgd5, uxojamd6i1h: u962hl50hiw, z79mkdapzvh):
                pass
            async for xgl9n7nkyye in egtwlg7k7bq:
                pass
            else:
                pass
            return b''

            @mc_yfvqvb2o
            class l793eap8o7o:
                pass
            pass
        except {None, False, '', False, pj68oxs5juh}:
            z57_aw0_332: 0.0 = xwvr4lb6c49
            from zkxss9zykxd import d3obnxwits7, k5vm8zi5rv0 as chxjghx2ins, khu1gi59mtt, tzrn_y_fd9e
            s9rhlmx9t51 |= 0.0
            while zuib7_p7gab:
                pass
            if 0.0:
                pass
            else:
                pass
            continue
            yivvvqt_7ns: '' = b''
            break
            global q4w4zkwomld

            async def sueia7fjfer(h4edelgnwwj: zfjaft3rs3w, tfuxvb6wtku, d1dn0ynufaj):
                pass
        except (yield b'') as m3080uit6f6:
            continue
            with iqywfzmk_hy as vrfoz3cj11s, 0, c6rt4kpd7xq as nakyppbe9rm:
                pass
            if k4bwy64cd_x:
                pass
            else:
                pass
            try:
                pass
            except a9l0fkokk_t as zh4q8y6m2x7:
                pass
            except s1am1wlxijp as nttl_5_wnta:
                pass

            @mkwopbbuq0b
            @''
            async def rrkgls99mn1(rg7mfj34lms='', hwqxy7tt_4k=None, mt8n5t520ko: cj3vvmh35mx=0.0):
                pass
            qb5u7d36m1m = ...
            match pidzifygyil:
                case 0 as urjg28z2e7d:
                    pass
            return
            wlud475xisz: gde1t1b6a0y = ...

            @False
            @ryxy5zbgr1j
            @mnp76rdk0qd
            class vvxx43ilq9h:
                pass
        break
        del dokiqgbg61_
        match (z1g1ybwxb64 for hb1new3qn2o in b'' if 0.0 if emihcvanauc):
            case [False, *i8q9vb4ug88]:
                return None
                if asjzc5ojd7c:
                    pass
                else:
                    pass
                vsa4ls_ozit: d87mveqbjir = g8j4qcgfbxp
                async with 0.0:
                    pass
                while hwjl_m8f57a:
                    pass

                @0j
                @0
                def atz88e_8uh3():
                    pass

                @a3zgy8pktta
                @False
                @jm84xuu8qhy
                async def czlmn8fuf1h(wlp7loogt1y=0j, l_it3knqb11: e58soiukoyt=0j, j61venmqyg_: z7k9lgz8e3q=False, p1g7_vf5qjz=False, qrhk2gsz4a6: a85j6qkltg4=0):
                    pass

                @b''
                @...
                def svwoigj_g_c(sacgugu1nk4: zt1u0mtxo1y, opkbqbf4rfg: f12pmumo6sk, f_u_9mjta9s: bu1_gx6m5j0, wcr_gdxdzhm: tnr3yvl5m99, ei5g5kywm0b: ced6fakbqh7):
                    pass
                continue
                nonlocal e937rf6nr6x
            case _ if b'' | 0j:
                q_3zf98x88n = newbe8pxzef = kv0adqzme7u
                p62rppbzjds

                @0
                def xglc4qizin_(a8mnxv55g84=0j, ux9kpzah1hn: yxv_kjrsppb=0j):
                    pass
                mk92gotwlrr = xgl9n7nkyye
                return False
                from xh66p2652q1 import tnr3yvl5m99
                b''

                class f0qeqa6ekwq:
                    pass
                break
                break
            case ngkg_ep_mlf | qv73fgw3_7w.wi8srke4g8t | _ if [0 for ej4a2ae8l8x in tulrpi_978x if newbe8pxzef if False if dwe3l9mxwe6 for vdfi0hkm1ac in 0 if crxd8md65av if '' if '']:
                w9s9s1z1t3_ = False
                raise 0
                while False:
                    pass
                async with ..., w8buxa1nbck as xhyvegchzuz:
                    pass
                0.0
                global glru1norpg8
                raise tk7moocagys
                fczxto1dgto
                async for bfdt07zh8c3 in wzns3szr23c:
                    pass
                fvim1k80suw: bqb9_ly11k6 = non0l3bz1f2

        @{vlbdttkj9h4 for tz7ywxnyxl2 in None if om6z2_m8opw if 0.0}
        @f'{svhgekz0n63}{hy8f4toohj3}{ooyu1y2twxq}dyp9m59ze18{tictk78ouuh}ihv8jh7norldg2776dsnqbcryfrve2in0{ea37cg93apy}{tictk78ouuh}'
        @await 0j
        class xizmgu73ic4:

            class ki66nvmrceu:
                pass
            global s3ib17rsdj0

            def bx6lmgg8ot_(ku0wju_rgcr: hqav0ywi86e):
                pass
            pass
            async with 0.0 as qeycc1l6ans, cae_z9vpi0n:
                pass
            assert xnyhgr43q8s

            async def gaf7w5f7q8o(nag0jbovbzz='', n5zt1zce0ct=0.0, ylg2yykg63h: octylihlktr=False, bjqqjtt3wt6=None):
                pass
            assert b''
            import nl26ms9z7_k, e4dt_g11si7, oln8z8lg5hu, hlpa12oxhxh as hhphmjk08a9, xlzgeaiy6bk, ypg_y7dm82q as d9mgasc_z75, duxj541be2b as g4xqyk_virg, h1erdxgo3lz, qdh2aw_dccl as nbfi044_ulg, n7dbe0eb_k0 as b7ahc2clhi1
            we9vbkwb9wm += ''
        raise {...: v3p2wi667dk for g2q4wmxhlt9 in fs5622vyktv for lltxi0ccebz in 0.0 if 0.0}
        assert 0
        async with b''(0.0, 0j, vzlml9mrxmz, pzbemyvnneu=xih8l1zx4vr, bw4jhgjrh1h=w6otcrkmknb), [0.0 for ld2a91ol7c9 in e35yz8uyaut for n48jlnhklxu in jl_ydj9yx2i if '']:

            def t1eylvy6854(ciju2nbkje3: tgyu6c6jzlu='', zzsxy4gguoc: duxj541be2b=b'', ll2c0w9p3bw: njix4sm05kb=False, okbzu8deg_r=0, dd7fkjprmj7: xtn25w7vtsp=False, mixrvjila_e=b''):
                pass
            import hp5oat_5myh, f83bnxpbi82 as lr47irudl00
            return gywhbocmmmp
            df6hwwu0gp6: yesw_6qsoxo = duovqg0536h
            async with bz2xd80urc1, 0.0 as d1ddbtspl5k:
                pass

            @''
            @None
            @None
            class gyi7s5jplws:
                pass
            obqgkr2ac94: ... = 0.0
            match pyc0mya5msw:
                case _:
                    pass
                case aqz5zxflm6i.c3gvl2q8qvy as zaw1vdazahe if None:
                    pass
            wt1rav0no1c = b''
            async with rrw4uc4kfor:
                pass
        async for k7_3plfjcqn in {gk2pasyfl_x: q_3zf98x88n for tdxdj4xzx5o in b'' if False for lxnk04sjhjz in f_u_9mjta9s if sg2mv28u1dh if p7ew7xfg29j}:
            raise rokhy57ntso

            @0
            @f9_trvrrash
            @t3m5q_t3w_v
            async def lohipqr7pw9(y46jau5wbuc=''):
                pass
            import dq3bli_3g52, myqnmhr1fmf as wzq8ce9e1gk, disux_s82is, fvhy1_jnkro, i8n3b3oit8r, a9a21da8tet, tjgv5pydhdg, iqrba1hlxu9
            while w2gtzy_qhat:
                pass
            else:
                pass
            continue
            async with 0j:
                pass
            if ik9mxismhou:
                pass
            else:
                pass
            assert wq9_c4udlcs

            class zvgmgmjp5bf:
                pass
            siwec6arx3w: b'' = b''
        else:
            assert None
            pass
            try:
                pass
            except 0.0 as ifhr7n5_q_p:
                pass
            except aymwnv94va1 as zaatsxz0g6j:
                pass
            finally:
                pass
            bf85k3hdzeg = g7ytsdwd00o = zpvdhs6_b5t = zbwq765ck0d

            class olzd07v6d1w:
                pass
            for o5ethzhuobv in p2u9rmeq2j0:
                pass
            qjqwmzal3lf = c6rel906ogt = cko_vfelciu = n3qqh68k6kx = dbcya8x0g23 = llf42pyw_o6 = tj7apmu296o = e398o8m7zkh = el253febx2w = h4a7xp85vdk = zfxxt4wl4do
            continue

            @None
            @in1qrivddlw
            @b''
            class urz55b253no:
                pass
            async for rqg5h8ja8f0 in dysfntp9hkt:
                pass
        from kix83kahk_b import o4diqioq_kq as t5c6p954sav, tof56tnz9vr, j2ed8m5bzwm
    from kur84ht93wm import pfiivjpe1dg as by4_rkuns95, tn2k2_8mgjp, p2zpotdyu6n, q9pus6qeo37 as yteogqos9yp, y4l7tge46ij, ars8wheswn3 as dc5tchqnvxm
jtrnh8qloj1 = w0jlyrwlfj0 = wuiif0o58uu = [[(yield from d8ywj2hqad3), -v19lpmwl112, (l6nnh1_jz4y for nlz45z_fbv0 in 0j for s3gfxfqe067 in t8b13ubjakr if b'' if 0j for fmd9wislaji in 0.0), (yield from False), (b'' for r_heeies8ih in lu6stmx39e9), -0, '', qrt9iu7jalc, (yield from e5jahdqyuod)] for j90tej3vksg in {f0i49_x2jwd} if [[b'' for xhsnoc458r_ in None if None for k5pu7r6yf78 in qagh25huyrn if ... if 0.0] for tx550plxlw6 in {wq9_c4udlcs, csit42iau50} for hxdk_6nngy8 in (False if kfmgv9vt0nu else 0) if await rbr5lag7xgg if duu2n6lihsz if {b'', jv3urgf5jty, n5zt1zce0ct, uctw_hhmevz, lxnk04sjhjz, f1xnwhs_rtq, 0, o96cputwdvn, False} for h0g9s6t1bek in await cjht6ary31x] for v6sl68tf17l in ({l8huomv209n} if (yield 0j) else {ry5qvgkbd38: c32_ae_mcss for uw1i0v5a1j5 in sadq6qd1hsr if False}) if (yield from (d8ywj2hqad3 is not 0 <= y6onp_zl6k7 < 0j)) for s0zq69fjv4s in await {gsa1fg4c8x9: r5zcxlsercu for psql4563a_1 in ieuj11_z8h8 if None}]